(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    377822,       6752]
NotebookOptionsPosition[    375137,       6694]
NotebookOutlinePosition[    375578,       6711]
CellTagsIndexPosition[    375535,       6708]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Growth of 1D surface - kinetic MC", "Title",
 CellChangeTimes->{{3.8498659197237196`*^9, 3.8498659353906155`*^9}, {
  3.8502884358260317`*^9, 3.850288452690901*^9}, {3.8504078931535835`*^9, 
  3.8504079297240343`*^9}, {3.8587553024030123`*^9, 3.8587553131456265`*^9}, {
  3.8590868568250656`*^9, 
  3.859086866595101*^9}},ExpressionUUID->"b15229c8-5a8d-4e56-afb3-\
39951f71899b"],

Cell[CellGroupData[{

Cell["\<\
General function for KMC returning the growth of the 1D surface with given \
rates and periodic boundary conditions\
\>", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502851174278107`*^9}, {
  3.8502884635283027`*^9, 3.8502884649516716`*^9}, {3.850407943113345*^9, 
  3.8504079457856646`*^9}, {3.8504449061005325`*^9, 3.8504449155490723`*^9}, {
  3.850446227606118*^9, 3.8504462511734657`*^9}, {3.8587553227221746`*^9, 
  3.8587553695458527`*^9}, {3.858764261860464*^9, 3.858764277268345*^9}, {
  3.859086875235243*^9, 3.859086877495412*^9}, {3.859087101665658*^9, 
  3.8590871056250563`*^9}},ExpressionUUID->"0df30b08-34d4-4ecd-a531-\
7a8c91a746de"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"initialState_", ",", "rates_", ",", "nsteps_", ",", "nsave_"}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"input", ":", " ", "\[IndentingNewLine]", "initialState"}], " ",
       "=", " ", 
      RowBox[{"2", "-", 
       RowBox[{
        RowBox[{"dim", ".", " ", "array"}], " ", "of", " ", "values", " ", 
        "0"}]}]}], ",", " ", 
     RowBox[{
     "1", " ", "or", " ", "2", " ", "for", " ", "each", " ", "lattice", " ", 
      "site", "\[IndentingNewLine]", "   ", "where", " ", "1", " ", "stands", 
      " ", "for", " ", "an", " ", "atom", " ", "of", " ", "the", " ", 
      "surface", " ", "and", " ", "0", " ", "for", " ", "an", " ", "empty", 
      " ", "site"}], ",", "\[IndentingNewLine]", "    ", 
     RowBox[{
      RowBox[{
      "and", " ", "2", " ", "is", " ", "an", " ", "atom", " ", "of", " ", 
       "the", " ", "substrate", " ", 
       RowBox[{"(", "unmovable", ")"}]}], " ", "-", " ", 
      RowBox[{"the", " ", "bottom", " ", "line", " ", "only"}]}], ",", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{"rates", " ", "=", " ", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"dim", ".", " ", "array"}], " ", "of", " ", "rates", " ", 
        RowBox[{"(", 
         RowBox[{
         "number", " ", "of", " ", "particular", " ", "events", " ", "per", 
          " ", "second"}], ")"}]}]}]}], ",", "\[IndentingNewLine]", 
     "        ", 
     RowBox[{
      RowBox[{"rates", "\[LeftDoubleBracket]", 
       RowBox[{"1", "-", "3"}], "\[RightDoubleBracket]"}], " ", "=", " ", 
      RowBox[{"deposition", " ", "rates", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"for", " ", "sites", " ", "with", " ", "1", " ", "bond"}], 
         ",", " ", 
         RowBox[{"2", " ", "bonds", " ", "and", " ", "3", " ", "bonds"}]}], 
        ")"}]}]}], ",", "\[IndentingNewLine]", "        ", 
     RowBox[{
      RowBox[{"rates", "\[LeftDoubleBracket]", 
       RowBox[{"4", "-", "6"}], "\[RightDoubleBracket]"}], " ", "=", " ", 
      RowBox[{"evaporation", " ", "rate", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"for", " ", "sites", " ", "with", " ", "1", " ", "bond"}], 
         ",", " ", 
         RowBox[{"2", " ", "bonds", " ", "and", " ", "3", " ", "bonds"}]}], 
        ")"}]}]}], ",", "\[IndentingNewLine]", "        ", 
     RowBox[{
      RowBox[{"rates", "\[LeftDoubleBracket]", 
       RowBox[{"7", "-", "9"}], "\[RightDoubleBracket]"}], " ", "=", " ", 
      RowBox[{
      "migration", " ", "rate", " ", "to", " ", "the", " ", "left", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"for", " ", "sites", " ", "with", " ", "1", " ", "bond"}], 
         ",", " ", 
         RowBox[{"2", " ", "bonds", " ", "and", " ", "3", " ", "bonds"}]}], 
        ")"}]}]}], ",", "\[IndentingNewLine]", "        ", 
     RowBox[{
      RowBox[{"rates", "\[LeftDoubleBracket]", 
       RowBox[{"10", "-", "12"}], "\[RightDoubleBracket]"}], " ", "=", " ", 
      RowBox[{
      "migration", " ", "rate", " ", "to", " ", "the", " ", "right", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"for", " ", "sites", " ", "with", " ", "1", " ", "bond"}], 
         ",", " ", 
         RowBox[{"2", " ", "bonds", " ", "and", " ", "3", " ", "bonds"}]}], 
        ")"}]}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"nsteps", " ", "=", " ", 
      RowBox[{
      "the", " ", "number", " ", "of", " ", "steps", " ", "to", " ", "be", 
       " ", "taken"}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"nsave", " ", "=", " ", 
      RowBox[{
      "after", " ", "how", " ", "many", " ", "steps", " ", "to", " ", "save", 
       " ", "the", " ", "lattice"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"output", ":", "\[IndentingNewLine]", "times"}], " ", "=", " ", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"dim", ".", " ", "array"}], " ", "of", " ", "times", " ", 
        "after", " ", "each", " ", "steps", " ", "determined", " ", "from", 
        " ", "rates"}]}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"latticeEvolution", " ", "=", " ", 
      RowBox[{"3", "-", 
       RowBox[{
        RowBox[{"dim", ".", " ", "array"}], " ", "of", " ", "evolution", " ", 
        "of", " ", "the", " ", "whole", " ", "lattice"}]}]}], ",", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{"meanHeights", " ", "=", " ", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"dim", ".", " ", "array"}], " ", "of", " ", "mean", " ", 
        "height", " ", "of", " ", "the", " ", "crystal", " ", "as", " ", "a", 
        " ", "function", " ", "of", " ", "time", " ", 
        RowBox[{"(", "steps", ")"}]}]}]}], ",", "\[IndentingNewLine]", "  ", 
     RowBox[{"surfaceRoughness", " ", "=", " ", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"dim", ".", " ", "array"}], " ", "of", " ", "mean", " ", 
        "roughness", " ", "as", " ", "a", " ", "function", " ", "of", " ", 
        "time", " ", 
        RowBox[{"(", "steps", ")"}]}]}]}], ","}], "\[IndentingNewLine]", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "m", ",", "n", ",", "np", ",", "plus", ",", " ", "minus", ",", 
       "currentLattice", ",", "times", ",", "latticeEvolution", ",", 
       "heights", ",", "nBonds", ",", "nNewBonds", ",", "nEvents", ",", 
       "events", ",", "meanHeights", ",", "surfaceRoughness", ",", 
       "totalProcessRates", ",", "totalRate", ",", "xi", ",", "chosenProcess",
        ",", "tempRate", ",", "chosenEvent", ",", "countEvents", ",", 
       "chosenSite"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m", ",", "n"}], "}"}], "=", 
       RowBox[{"Dimensions", "[", 
        RowBox[{"initialState", ",", "2"}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"size", " ", "of", " ", "the", " ", "2", "D", " ", "lattice"}],
        " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"np", "=", 
       RowBox[{"Length", "[", "rates", "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"number", " ", "of", " ", "processes"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "auxiliary", " ", "arrays", " ", "for", " ", "simple", " ", 
        "treatment", " ", "of", " ", "periodic", " ", "boundary", " ", 
        "conditions"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"plus", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "+", 
           RowBox[{"Mod", "[", 
            RowBox[{"#", ",", "n"}], "]"}]}], "&"}], ",", "n"}], "]"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"minus", "=", 
       RowBox[{"Array", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "+", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"#", "-", "2"}], ",", "n"}], "]"}]}], "&"}], ",", "n"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"auxiliary", " ", "array", " ", "for", " ", "evolution"}], " ",
        "*)"}], "\[IndentingNewLine]", 
      RowBox[{"currentLattice", "=", "initialState"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"arrays", " ", "for", " ", "output"}], ",", " ", 
        RowBox[{
        "only", " ", "some", " ", "lattices", " ", "are", " ", "saved", " ", 
         "for", " ", "plotting"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"times", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0.0", ",", 
         RowBox[{"nsteps", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"latticeEvolution", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"initialState", ",", 
         RowBox[{
          RowBox[{"Floor", "[", 
           RowBox[{"nsteps", "/", "nsave"}], "]"}], "+", "1"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"meanHeights", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0.0", ",", 
         RowBox[{"nsteps", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"surfaceRoughness", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0.0", ",", 
         RowBox[{"nsteps", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "determine", " ", "the", " ", "initial", " ", "mean", " ", "height", 
        " ", "and", " ", "surface", " ", "roughness"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"heights", "=", 
       RowBox[{
        RowBox[{"Total", "[", "initialState", "]"}], "-", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
       "meanHeights", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "=", 
       RowBox[{"Mean", "[", "heights", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
       "surfaceRoughness", "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}], "=", 
       RowBox[{"StandardDeviation", "[", "heights", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", "evolution", " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "initial", " ", "number", " ", "of", " ", "bonds", " ", "for", " ", 
         "the", " ", "highest", " ", "lying", " ", "atom", " ", "at", " ", 
         "each", " ", "site"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"nBonds", "=", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"1", ",", "n"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "heights", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], ",", 
             RowBox[{
              RowBox[{
              "nBonds", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], "=", "0"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{"otherwise", " ", "count", " ", "bonds"}], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "heights", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LessEqual]", 
                 RowBox[{"heights", "\[LeftDoubleBracket]", 
                  RowBox[{
                  "plus", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}]}], 
                ",", 
                RowBox[{
                 RowBox[{
                 "nBonds", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "++"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "heights", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LessEqual]", 
                 RowBox[{"heights", "\[LeftDoubleBracket]", 
                  RowBox[{
                  "minus", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}]}], 
                ",", 
                RowBox[{
                 RowBox[{
                 "nBonds", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "++"}]}], "]"}]}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "\[IndentingNewLine]",
           "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "initial", " ", "number", " ", "of", " ", "new", " ", "bonds", " ", 
           "for", " ", "an", " ", "incoming", " ", "atom", " ", "at", " ", 
           "each", " ", "site"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"nNewBonds", "=", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"1", ",", "n"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "heights", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "<", 
               RowBox[{"heights", "\[LeftDoubleBracket]", 
                RowBox[{
                "plus", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}]}], ",", 
              RowBox[{
               RowBox[{
               "nNewBonds", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "++"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "heights", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "<", 
               RowBox[{"heights", "\[LeftDoubleBracket]", 
                RowBox[{
                "minus", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}]}], ",", 
              RowBox[{
               RowBox[{
               "nNewBonds", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "++"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "\[IndentingNewLine]",
           "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
           "initialize", " ", "the", " ", "number", " ", "and", " ", 
            "positions", " ", "of", " ", "possible", " ", "elementary", " ", 
            "events"}], ",", " ", "\[IndentingNewLine]", "   ", 
           RowBox[{
           "similar", " ", "to", " ", "the", " ", "input", " ", "arrays", 
            " ", "\"\<rates\>\""}], ",", "\[IndentingNewLine]", "   ", 
           RowBox[{
           "only", " ", "each", " ", "element", " ", "contains", " ", "the", 
            " ", "number", " ", "of", " ", "events", " ", "or", " ", "a", " ",
             "list", " ", "of", " ", "0", "s", " ", "or", " ", "1", "s", 
            "\[IndentingNewLine]", "  ", "whether", " ", "the", " ", 
            "corresponding", " ", "process", " ", "can", " ", "occur", " ", 
            "on", " ", "a", " ", "given", " ", "site"}]}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"nEvents", "=", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"0", ",", "np"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"events", "=", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"np", ",", "n"}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Do", "[", " ", 
          RowBox[{"(*", " ", 
           RowBox[{"loop", " ", "over", " ", "all", " ", "sites"}], " ", 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"(*", " ", "deposition", " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"nEvents", "\[LeftDoubleBracket]", 
              RowBox[{
              "nNewBonds", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], "++"}], 
            ";", 
            RowBox[{
             RowBox[{"events", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{
               "nNewBonds", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], ",", "i"}], 
              "\[RightDoubleBracket]"}], "=", "1"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "evaporation", " ", "or", " ", "migration", " ", "is", " ", 
              "possible", " ", "only", " ", "if", " ", "there", " ", "is", 
              " ", "an", " ", "atom", " ", "at", " ", "the", " ", "site"}], 
             " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "nBonds", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], ">", "0"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"nEvents", "\[LeftDoubleBracket]", 
                 RowBox[{"3", "+", 
                  RowBox[{
                  "nBonds", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                "++"}], ";", 
               RowBox[{
                RowBox[{"events", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"3", "+", 
                   RowBox[{
                   "nBonds", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}]}], ",", "i"}], 
                 "\[RightDoubleBracket]"}], "=", "1"}], ";", " ", 
               RowBox[{"(*", " ", "evaporation", " ", "*)"}], 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"nEvents", "\[LeftDoubleBracket]", 
                 RowBox[{"6", "+", 
                  RowBox[{
                  "nBonds", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                "++"}], ";", 
               RowBox[{
                RowBox[{"events", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"6", "+", 
                   RowBox[{
                   "nBonds", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}]}], ",", "i"}], 
                 "\[RightDoubleBracket]"}], "=", "1"}], ";", " ", 
               RowBox[{"(*", " ", 
                RowBox[{"migration", " ", "to", " ", "the", " ", "left"}], 
                " ", "*)"}], "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"nEvents", "\[LeftDoubleBracket]", 
                 RowBox[{"9", "+", 
                  RowBox[{
                  "nBonds", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                "++"}], ";", 
               RowBox[{
                RowBox[{"events", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"9", "+", 
                   RowBox[{
                   "nBonds", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}]}], ",", "i"}], 
                 "\[RightDoubleBracket]"}], "=", "1"}]}]}], " ", 
             RowBox[{"(*", " ", 
              RowBox[{"migration", " ", "to", " ", "the", " ", "right"}], " ",
               "*)"}], "\[IndentingNewLine]", "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "\[IndentingNewLine]",
           "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "determine", " ", "which", " ", "process", " ", "will", " ", 
           "occur"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"totalProcessRates", "=", 
          RowBox[{"nEvents", "*", "rates"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"totalRate", "=", 
          RowBox[{"Total", "[", "totalProcessRates", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xi", "=", 
          RowBox[{"RandomReal", "[", "totalRate", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"chosenProcess", "=", "0"}], ";", 
         RowBox[{"tempRate", "=", "0.0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"tempRate", "<", "xi"}], ",", 
           RowBox[{
            RowBox[{"chosenProcess", "++"}], ";", 
            RowBox[{"tempRate", "+=", 
             RowBox[{
             "totalProcessRates", "\[LeftDoubleBracket]", "chosenProcess", 
              "\[RightDoubleBracket]"}]}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "determine", " ", "which", " ", "elementary", " ", "event", " ", 
           "will", " ", "occur"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"chosenEvent", "=", 
          RowBox[{"RandomInteger", "[", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{
             "nEvents", "\[LeftDoubleBracket]", "chosenProcess", 
              "\[RightDoubleBracket]"}]}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"chosenSite", "=", "0"}], ";", 
         RowBox[{"countEvents", "=", "0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"countEvents", "<", "chosenEvent"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"chosenSite", "++"}], ";", "\[IndentingNewLine]", 
            RowBox[{"countEvents", "+=", 
             RowBox[{"events", "\[LeftDoubleBracket]", 
              RowBox[{"chosenProcess", ",", "chosenSite"}], 
              "\[RightDoubleBracket]"}]}], ";"}]}], "\[IndentingNewLine]", 
          "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{
            "\"\<Chosen process: \>\"", ",", "chosenProcess", ",", 
             "\"\<, chosen event: \>\"", ",", "chosenEvent", ",", 
             "\"\<, chosen site: \>\"", ",", "chosenSite"}], "]"}], ";"}], 
          " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{"do", " ", "the", " ", "chosen", " ", "process"}], " ", 
          "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"chosenProcess", "<", "4"}], ",", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", "deposition", " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
             "heights", "\[LeftDoubleBracket]", "chosenSite", 
              "\[RightDoubleBracket]"}], "++"}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"currentLattice", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"m", "-", 
                RowBox[{
                "heights", "\[LeftDoubleBracket]", "chosenSite", 
                 "\[RightDoubleBracket]"}]}], ",", "chosenSite"}], 
              "\[RightDoubleBracket]"}], "=", "1"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"evaporation", " ", "or", " ", "migration"}], " ", "*)"}],
            "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"currentLattice", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"m", "-", 
                RowBox[{
                "heights", "\[LeftDoubleBracket]", "chosenSite", 
                 "\[RightDoubleBracket]"}]}], ",", "chosenSite"}], 
              "\[RightDoubleBracket]"}], "=", "0"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
             "heights", "\[LeftDoubleBracket]", "chosenSite", 
              "\[RightDoubleBracket]"}], "--"}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"chosenProcess", ">", "6"}], " ", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", " ", 
               RowBox[{
                RowBox[{"chosenProcess", "<", "10"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{"migration", " ", "to", " ", "the", " ", "left"}], 
                 " ", "*)"}], "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"heights", "\[LeftDoubleBracket]", 
                   RowBox[{
                   "minus", "\[LeftDoubleBracket]", "chosenSite", 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], 
                  "++"}], ";", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"currentLattice", "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"m", "-", 
                    RowBox[{"heights", "\[LeftDoubleBracket]", 
                    RowBox[{
                    "minus", "\[LeftDoubleBracket]", "chosenSite", 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}]}], 
                    ",", 
                    RowBox[{
                    "minus", "\[LeftDoubleBracket]", "chosenSite", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                  "=", "1"}]}], ",", "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{"migration", " ", "to", " ", "the", " ", "right"}], 
                 " ", "*)"}], "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"heights", "\[LeftDoubleBracket]", 
                   RowBox[{
                   "plus", "\[LeftDoubleBracket]", "chosenSite", 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], 
                  "++"}], ";", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"currentLattice", "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"m", "-", 
                    RowBox[{"heights", "\[LeftDoubleBracket]", 
                    RowBox[{
                    "plus", "\[LeftDoubleBracket]", "chosenSite", 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}]}], 
                    ",", 
                    RowBox[{
                    "plus", "\[LeftDoubleBracket]", "chosenSite", 
                    "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], 
                  "=", "1"}]}]}], "\[IndentingNewLine]", "]"}]}], 
             "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{"save", " ", "physical", " ", "quantities"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"times", "\[LeftDoubleBracket]", 
           RowBox[{"it", "+", "1"}], "\[RightDoubleBracket]"}], "=", 
          RowBox[{
           RowBox[{
           "times", "\[LeftDoubleBracket]", "it", "\[RightDoubleBracket]"}], 
           "-", 
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"RandomReal", "[", "]"}], "]"}], "/", "totalRate"}]}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"meanHeights", "\[LeftDoubleBracket]", 
           RowBox[{"it", "+", "1"}], "\[RightDoubleBracket]"}], "=", 
          RowBox[{"Mean", "[", "heights", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"surfaceRoughness", "\[LeftDoubleBracket]", 
           RowBox[{"it", "+", "1"}], "\[RightDoubleBracket]"}], "=", 
          RowBox[{"StandardDeviation", "[", 
           RowBox[{"N", "[", "heights", "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Mod", "[", 
             RowBox[{"it", ",", "nsave"}], "]"}], "\[Equal]", "0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"latticeEvolution", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{"it", "/", "nsave"}], "+", "1"}], 
             "\[RightDoubleBracket]"}], "=", "currentLattice"}]}], 
          "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"it", ",", "1", ",", "nsteps"}], "}"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"{", 
        RowBox[{
        "times", ",", "meanHeights", ",", "surfaceRoughness", ",", 
         "latticeEvolution"}], "}"}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8496065737332587`*^9, 3.849606654427*^9}, {
   3.8496066854068832`*^9, 3.8496066856924987`*^9}, {3.8496067692497735`*^9, 
   3.849606771348775*^9}, {3.8496068224442654`*^9, 3.8496068951102657`*^9}, {
   3.849606941073992*^9, 3.8496069670037174`*^9}, {3.849607002220313*^9, 
   3.8496074760208178`*^9}, {3.8496077119325123`*^9, 3.849607748132677*^9}, {
   3.8498659522565804`*^9, 3.849866234045698*^9}, {3.8498664501880603`*^9, 
   3.849866560979398*^9}, {3.849866608770131*^9, 3.8498667563615727`*^9}, {
   3.849866795952837*^9, 3.8498668229203796`*^9}, {3.849866856288288*^9, 
   3.8498669046880565`*^9}, {3.8498669577040887`*^9, 
   3.8498669937121487`*^9}, {3.849867326660192*^9, 3.8498675569833655`*^9}, {
   3.8498677067099295`*^9, 3.849867729758248*^9}, {3.849867794714963*^9, 
   3.8498679708510375`*^9}, {3.8498680893228135`*^9, 
   3.8498681521384068`*^9}, {3.8498682229434566`*^9, 
   3.8498682412875056`*^9}, {3.8498682825118637`*^9, 3.849868329421547*^9}, {
   3.849868428544216*^9, 3.8498684496614237`*^9}, {3.849868692556317*^9, 
   3.8498687736739564`*^9}, {3.8498688480182085`*^9, 
   3.8498688742667103`*^9}, {3.849868979090706*^9, 3.8498690248643236`*^9}, {
   3.8498690758832417`*^9, 3.849869083128656*^9}, {3.8498691286262584`*^9, 
   3.84986920680873*^9}, {3.849869250843249*^9, 3.8498692561335516`*^9}, {
   3.849869287120324*^9, 3.8498693018551664`*^9}, {3.849869419129874*^9, 
   3.849869486052702*^9}, {3.849869551278433*^9, 3.8498695722186303`*^9}, {
   3.850209338624843*^9, 3.8502093666224446`*^9}, {3.8502094626939397`*^9, 
   3.850209506746459*^9}, {3.8502095758124094`*^9, 3.850209612623515*^9}, {
   3.8502097222337847`*^9, 3.8502097240948906`*^9}, {3.850209784338337*^9, 
   3.850209804590495*^9}, {3.85021004804742*^9, 3.8502100678515525`*^9}, {
   3.8502823883410573`*^9, 3.8502823904519043`*^9}, {3.8502827091554527`*^9, 
   3.8502827305592375`*^9}, {3.8502827633875566`*^9, 3.850282770436743*^9}, {
   3.850282809667946*^9, 3.850283014461815*^9}, {3.8502830628918743`*^9, 
   3.8502833755911655`*^9}, {3.8502834085701785`*^9, 3.850283420387255*^9}, {
   3.850283596583228*^9, 3.850283597528829*^9}, {3.850283844925599*^9, 
   3.850283883214069*^9}, {3.8502839989512444`*^9, 3.850284008881238*^9}, {
   3.850284444798033*^9, 3.850284445065889*^9}, {3.8502846732782197`*^9, 
   3.850284741112954*^9}, {3.850284922195149*^9, 3.850284923148017*^9}, {
   3.8502851222664003`*^9, 3.8502851244583917`*^9}, 3.850286085594694*^9, {
   3.850286679977948*^9, 3.850286703311764*^9}, {3.8502869522880197`*^9, 
   3.8502871242314744`*^9}, {3.8502871663999095`*^9, 
   3.8502871678013754`*^9}, {3.850288488694371*^9, 3.850288522186626*^9}, {
   3.8502885981612406`*^9, 3.8502886355455885`*^9}, {3.8502991493940296`*^9, 
   3.8502991738098364`*^9}, {3.8502992349912353`*^9, 3.850299246362059*^9}, {
   3.8502993318357267`*^9, 3.850299348849098*^9}, {3.850299381766471*^9, 
   3.8502996020037723`*^9}, {3.8502997381470404`*^9, 3.850299822578452*^9}, {
   3.850299907763318*^9, 3.8503000556463923`*^9}, {3.850300113499284*^9, 
   3.850300153813047*^9}, {3.850300260418194*^9, 3.850300333934967*^9}, {
   3.8503003745621414`*^9, 3.8503003749608736`*^9}, 3.8503004195304165`*^9, {
   3.8503004674465656`*^9, 3.850300477941496*^9}, {3.8503010662506666`*^9, 
   3.850301253842307*^9}, {3.850301305078566*^9, 3.850301306922103*^9}, {
   3.850301355617137*^9, 3.8503014822213535`*^9}, {3.8503015812921886`*^9, 
   3.850301637662247*^9}, {3.850301721175931*^9, 3.850301818225009*^9}, {
   3.850302006250021*^9, 3.8503020322460113`*^9}, {3.8503020670259323`*^9, 
   3.850302133564114*^9}, {3.850302166479986*^9, 3.850302224098697*^9}, {
   3.8503022558635283`*^9, 3.850302285007962*^9}, {3.850302378289647*^9, 
   3.850302507333518*^9}, {3.850302563268634*^9, 3.850302563901643*^9}, {
   3.850305309239606*^9, 3.8503054709155135`*^9}, {3.850306308238212*^9, 
   3.850306311398385*^9}, {3.850306342873065*^9, 3.850306421387246*^9}, {
   3.8503064627927437`*^9, 3.8503065650437765`*^9}, {3.8503065999805307`*^9, 
   3.8503066580431275`*^9}, {3.850306703344405*^9, 3.850306920178565*^9}, {
   3.850306964667661*^9, 3.850307050066254*^9}, {3.8503070892171*^9, 
   3.8503070949580555`*^9}, {3.8503071579808345`*^9, 3.85030716108549*^9}, {
   3.8503074109208455`*^9, 3.8503074124391117`*^9}, {3.8503074627379093`*^9, 
   3.8503074731979485`*^9}, {3.850307601886543*^9, 3.850307631581897*^9}, {
   3.8503077342177167`*^9, 3.850307818409624*^9}, 3.8503078809044504`*^9, {
   3.8503079170340476`*^9, 3.850307944974044*^9}, {3.850308068703856*^9, 
   3.8503080821448064`*^9}, {3.8503081141002674`*^9, 3.8503081998117094`*^9}, 
   3.8503082486967936`*^9, {3.850309877717277*^9, 3.8503099293016024`*^9}, {
   3.850310006619562*^9, 3.850310033809697*^9}, {3.850310302493517*^9, 
   3.8503103145364757`*^9}, {3.8503197013229585`*^9, 
   3.8503197789306507`*^9}, {3.850319858615965*^9, 3.850319862884163*^9}, {
   3.8503203669429846`*^9, 3.850320369592593*^9}, {3.8504079506451187`*^9, 
   3.8504081787888556`*^9}, {3.8504082245844355`*^9, 3.850408228460683*^9}, {
   3.8504082702512283`*^9, 3.8504083433004293`*^9}, {3.850408391736351*^9, 
   3.8504084692662354`*^9}, {3.8504087677049923`*^9, 3.850409019284892*^9}, {
   3.8504090558370075`*^9, 3.8504090609312153`*^9}, {3.8504091022368665`*^9, 
   3.8504092822744045`*^9}, {3.850410055147817*^9, 3.850410098779961*^9}, {
   3.8504101562701273`*^9, 3.8504101590205097`*^9}, {3.850411243074305*^9, 
   3.850411301531823*^9}, {3.8504113795392327`*^9, 3.850411440279065*^9}, {
   3.8504116883696384`*^9, 3.8504116902135515`*^9}, {3.8504118383514524`*^9, 
   3.8504119601881313`*^9}, {3.8504120848238535`*^9, 
   3.8504120978282266`*^9}, {3.850412356139202*^9, 3.8504123886535387`*^9}, {
   3.8504124208751507`*^9, 3.8504127498974795`*^9}, {3.850414384318515*^9, 
   3.8504144098138947`*^9}, {3.850416289766465*^9, 3.8504163050832624`*^9}, {
   3.8504164348664446`*^9, 3.850416437320009*^9}, {3.8504165158598332`*^9, 
   3.850416518563015*^9}, {3.8504165491820536`*^9, 3.850416661477475*^9}, {
   3.8504167393187723`*^9, 3.850416771380473*^9}, {3.8504175895941625`*^9, 
   3.850417640639447*^9}, {3.8504453494788923`*^9, 3.8504453556452446`*^9}, 
   3.85044548126943*^9, {3.850446242941995*^9, 3.8504462663463335`*^9}, {
   3.858755384479707*^9, 3.8587557133135147`*^9}, {3.858755753281801*^9, 
   3.858755761433267*^9}, {3.8587560395981774`*^9, 3.858756162942232*^9}, {
   3.8587562102299366`*^9, 3.8587562110539837`*^9}, {3.8587564158836994`*^9, 
   3.8587564169627614`*^9}, {3.85875699966109*^9, 3.8587571621213818`*^9}, {
   3.8587590807131195`*^9, 3.858759183809016*^9}, {3.8587606227413177`*^9, 
   3.858760693324355*^9}, {3.858760731659548*^9, 3.8587607612192383`*^9}, {
   3.8587611374637585`*^9, 3.85876113767177*^9}, {3.85876385251305*^9, 
   3.8587638531290855`*^9}, {3.8587640260479765`*^9, 3.858764162086757*^9}, {
   3.8587642881109653`*^9, 3.858764314614481*^9}, {3.858764363229262*^9, 
   3.8587644381245456`*^9}, {3.858764492386649*^9, 3.85876455533925*^9}, {
   3.8587646723459425`*^9, 3.8587647022426524`*^9}, {3.8587647325853877`*^9, 
   3.858764981431621*^9}, {3.858765068940626*^9, 3.8587651155182905`*^9}, {
   3.8587653596982565`*^9, 3.858765488033597*^9}, {3.858767165349534*^9, 
   3.8587673193403416`*^9}, 3.8587674567552013`*^9, {3.858767754705243*^9, 
   3.85876776688894*^9}, {3.8587682446242647`*^9, 3.8587682512636447`*^9}, {
   3.8587682857516174`*^9, 3.858768361814968*^9}, {3.85876842094435*^9, 
   3.8587685768382664`*^9}, 3.8587686469142747`*^9, {3.858768732290158*^9, 
   3.8587687390925465`*^9}, 3.85876888268576*^9, {3.8587689261552467`*^9, 
   3.858768961681278*^9}, {3.858769029418153*^9, 3.858769095615939*^9}, {
   3.858769258905278*^9, 3.8587692627745*^9}, {3.858769311887309*^9, 
   3.8587693251740685`*^9}, {3.858769527754656*^9, 3.858769530411808*^9}, 
   3.858769609876353*^9, {3.8587701811910305`*^9, 3.858770199003049*^9}, {
   3.858770300620861*^9, 3.8587703270983753`*^9}, {3.858770539480523*^9, 
   3.8587705435027533`*^9}, {3.858771009663416*^9, 3.858771010356456*^9}, {
   3.858779899347877*^9, 3.858779963633554*^9}, {3.8587801350723596`*^9, 
   3.858780380095374*^9}, {3.85878046393417*^9, 3.8587804838133063`*^9}, {
   3.8587805139010277`*^9, 3.8587805399185157`*^9}, {3.858780593828599*^9, 
   3.858780619669077*^9}, {3.85878075155062*^9, 3.858780752179656*^9}, {
   3.8587815838712263`*^9, 3.8587816080866113`*^9}, {3.8587817936302233`*^9, 
   3.8587819116919765`*^9}, {3.8587819421887207`*^9, 3.858782022635322*^9}, {
   3.8587821551859035`*^9, 3.85878215565493*^9}, {3.858782587510631*^9, 
   3.858782756515298*^9}, {3.858782788923151*^9, 3.8587827999547825`*^9}, {
   3.858783493699462*^9, 3.858783494834527*^9}, 3.8587835426332607`*^9, {
   3.8587837010023193`*^9, 3.858783732184103*^9}, {3.858783777620702*^9, 
   3.8587837801038437`*^9}, {3.8587843336115026`*^9, 
   3.8587843857524843`*^9}, {3.8590868872847776`*^9, 
   3.8590868883449216`*^9}, {3.8590869932049932`*^9, 3.859086997285035*^9}, {
   3.8590871183716955`*^9, 3.859087311714726*^9}, {3.8592199617786036`*^9, 
   3.8592200784328613`*^9}, {3.8592201116487217`*^9, 
   3.8592201229391484`*^9}, {3.8592570920600643`*^9, 
   3.8592571483506436`*^9}, {3.859257180220093*^9, 3.859257181905306*^9}, {
   3.8592572414612827`*^9, 3.8592572776403184`*^9}, {3.8592573405800285`*^9, 
   3.859257416206154*^9}, {3.859257481080684*^9, 3.859257586510132*^9}, {
   3.8592576436702585`*^9, 3.859257647209829*^9}, 3.8592576782313113`*^9, {
   3.8596513017092853`*^9, 3.859651395368798*^9}, {3.859787458256192*^9, 
   3.859787462721012*^9}, {3.859787493060107*^9, 3.85978782940038*^9}, {
   3.859787978240177*^9, 3.859787984090581*^9}, {3.8597880755906663`*^9, 
   3.8597881180604525`*^9}, {3.859788175640462*^9, 3.8597883204825573`*^9}, {
   3.859789725954458*^9, 3.8597897618663797`*^9}, {3.859789914156496*^9, 
   3.8597900074949226`*^9}, {3.8597905698210955`*^9, 3.859790606915039*^9}, {
   3.8597912443148165`*^9, 3.859791430284619*^9}, {3.8597914822753425`*^9, 
   3.8597915324171195`*^9}, {3.859791675753708*^9, 3.859792057557379*^9}, {
   3.859792157980771*^9, 3.85979224241479*^9}, {3.859792861874793*^9, 
   3.859792867634964*^9}, {3.859792935644526*^9, 3.8597929595747614`*^9}, {
   3.8597930096245947`*^9, 3.8597930199251127`*^9}, {3.8597930701250105`*^9, 
   3.8597931004449377`*^9}, {3.859793203334445*^9, 3.859793302251625*^9}, 
   3.859801799236948*^9, {3.8598018494650927`*^9, 3.859801894905363*^9}, {
   3.8598019856979485`*^9, 3.8598021815775223`*^9}, {3.85980266010666*^9, 
   3.8598027202411394`*^9}, {3.859802766949521*^9, 3.859802767330839*^9}, {
   3.859802807697855*^9, 3.859802846739609*^9}, {3.8598064848568487`*^9, 
   3.859806644961177*^9}, {3.859806775576562*^9, 3.8598070494365263`*^9}, {
   3.8598071037367916`*^9, 3.859807134363014*^9}, {3.859807247537609*^9, 
   3.859807262848919*^9}, {3.85980734180792*^9, 3.85980736755752*^9}, {
   3.859807412207505*^9, 3.8598074549380455`*^9}, {3.8598074990974627`*^9, 
   3.859807515977479*^9}, {3.8598075520275154`*^9, 3.859807609821877*^9}, {
   3.859807753350533*^9, 3.859807757261707*^9}, {3.8598121386947155`*^9, 
   3.859812298242755*^9}, {3.859812333809679*^9, 3.8598124157402735`*^9}, {
   3.8598124999305177`*^9, 3.859812588749971*^9}, {3.8598126656402535`*^9, 
   3.8598127738797984`*^9}, {3.8598128418900585`*^9, 3.85981285841504*^9}, {
   3.85981359936158*^9, 3.859813601416766*^9}, {3.859813816770435*^9, 
   3.8598139423594227`*^9}, {3.859814028949789*^9, 3.859814117235928*^9}, {
   3.8598142151795573`*^9, 3.8598142941546326`*^9}, {3.8598143779098225`*^9, 
   3.859814418159937*^9}, {3.8598144980294447`*^9, 3.8598145347946234`*^9}, {
   3.859814573619766*^9, 3.859814637874447*^9}, {3.859814804024825*^9, 
   3.8598148142895555`*^9}, {3.8598148463895617`*^9, 3.859814909939965*^9}, {
   3.8598149438694515`*^9, 3.8598149819298935`*^9}, {3.8598150985698595`*^9, 
   3.8598151272797055`*^9}, {3.8598151753197074`*^9, 
   3.8598152039436264`*^9}, {3.859815239769616*^9, 3.8598155309692335`*^9}, {
   3.8598205080738487`*^9, 3.859820508474046*^9}, {3.859820841809708*^9, 
   3.8598208463045044`*^9}, {3.8598256983342285`*^9, 
   3.8598257055942893`*^9}, {3.881854643424302*^9, 3.8818546461962023`*^9}, {
   3.8818566334391603`*^9, 3.8818566351184053`*^9}, {3.8818658927471967`*^9, 
   3.881865899639125*^9}, {3.881865941081209*^9, 3.8818659443670287`*^9}},
 CellLabel->
  "In[470]:=",ExpressionUUID->"ecdda7ec-fa69-4d39-bc74-0c1c937e0baf"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples of growths", "Section",
 CellChangeTimes->{{3.850284992156113*^9, 3.8502850419545326`*^9}, {
  3.8502885423985496`*^9, 3.8502885531348696`*^9}, {3.850321714174992*^9, 
  3.8503217240349073`*^9}, {3.850321763569309*^9, 3.850321769186617*^9}, {
  3.850402362160965*^9, 3.8504023699393067`*^9}, {3.8504127857116175`*^9, 
  3.8504127996503525`*^9}, {3.8587563303118052`*^9, 
  3.8587563389593*^9}},ExpressionUUID->"97799fb6-f47e-46e0-a957-eef0312bf499"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"myListPlot", "[", 
    RowBox[{"model_", ",", "i_", ",", "label_", ",", "ims_"}], "]"}], ":=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"results", "[", 
         RowBox[{"model", ",", "1"}], "]"}], "\[LeftDoubleBracket]", "i", 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{"results", "[", 
         RowBox[{"model", ",", "2"}], "]"}], "\[LeftDoubleBracket]", "i", 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{"results", "[", 
         RowBox[{"model", ",", "3"}], "]"}], "\[LeftDoubleBracket]", "i", 
        "\[RightDoubleBracket]"}]}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<N\>\"", ",", "label"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "ims"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"myListLogLogPlot", "[", 
    RowBox[{"model_", ",", "i_", ",", "label_", ",", "ims_"}], "]"}], ":=", 
   RowBox[{"ListLogLogPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"results", "[", 
         RowBox[{"model", ",", "1"}], "]"}], "\[LeftDoubleBracket]", "i", 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{"results", "[", 
         RowBox[{"model", ",", "2"}], "]"}], "\[LeftDoubleBracket]", "i", 
        "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{"results", "[", 
         RowBox[{"model", ",", "3"}], "]"}], "\[LeftDoubleBracket]", "i", 
        "\[RightDoubleBracket]"}]}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<N\>\"", ",", "label"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "ims"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8818659762931595`*^9, 3.8818659995855265`*^9}, 
   3.881866539080473*^9},ExpressionUUID->"73299ce6-9e87-49f1-89e2-\
3ae98e6a1047"],

Cell[CellGroupData[{

Cell["Simple growth, no evaporation or migration", "Subsubsection",
 CellChangeTimes->{{3.8818589731334085`*^9, 
  3.8818590144666815`*^9}},ExpressionUUID->"75f56ec7-339a-4b01-8cb7-\
fd28b19030ea"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", ",", "n"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"40", ",", "60"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iniState", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"empty", " ", "everywhere"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"iniState", "\[LeftDoubleBracket]", 
    RowBox[{"m", ",", "All"}], "\[RightDoubleBracket]"}], "=", "2"}], ";", 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{"bottom", " ", "line"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"nsteps", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nsave", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "10", ",", "10", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "20", ",", "30", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "30", ",", "50", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"imageSize", "=", "300"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"myListPlot", "[", 
     RowBox[{"1", ",", "1", ",", "\"\<Time\>\"", ",", "imageSize"}], "]"}], 
    ",", 
    RowBox[{"myListPlot", "[", 
     RowBox[{"1", ",", "2", ",", "\"\<Mean Height\>\"", ",", "imageSize"}], 
     "]"}], ",", 
    RowBox[{"myListPlot", "[", 
     RowBox[{"1", ",", "3", ",", "\"\<Roughness\>\"", ",", "imageSize"}], 
     "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8502887065634837`*^9, 3.8502888963136773`*^9}, {
   3.850296451864761*^9, 3.850296952605251*^9}, {3.8502970639607067`*^9, 
   3.850297097374488*^9}, {3.850297593896261*^9, 3.8502977479125433`*^9}, {
   3.8502978475363164`*^9, 3.8502978543507624`*^9}, {3.8502978977622185`*^9, 
   3.8502979184872675`*^9}, {3.8502979781423087`*^9, 3.850298044495248*^9}, 
   3.850298075208606*^9, {3.850298134153597*^9, 3.850298229633453*^9}, {
   3.8503051135349236`*^9, 3.850305279617973*^9}, {3.850307256603691*^9, 
   3.8503072838162165`*^9}, {3.850307394898145*^9, 3.8503074024604597`*^9}, {
   3.8503075236844597`*^9, 3.8503075277829113`*^9}, {3.850307577252304*^9, 
   3.850307616956478*^9}, {3.8503077000071898`*^9, 3.8503077034139557`*^9}, {
   3.850307964016522*^9, 3.8503080173115416`*^9}, 3.85030823093408*^9, {
   3.850308287072387*^9, 3.850308376271407*^9}, {3.8503084185719295`*^9, 
   3.85030842657446*^9}, {3.8503085057561445`*^9, 3.8503085116283565`*^9}, {
   3.850308545339714*^9, 3.8503085729720297`*^9}, {3.850308957132331*^9, 
   3.85030896067314*^9}, {3.850309123923725*^9, 3.850309125384981*^9}, {
   3.850309211355878*^9, 3.850309240733102*^9}, {3.850309285394911*^9, 
   3.850309326211439*^9}, 3.8503093778709145`*^9, {3.8503094660718813`*^9, 
   3.8503094670110626`*^9}, {3.850309526303648*^9, 3.850309567884674*^9}, {
   3.85030969600125*^9, 3.850309700258051*^9}, {3.850318495607312*^9, 
   3.8503186014562716`*^9}, {3.85031866995634*^9, 3.8503186723647003`*^9}, {
   3.8503197940242667`*^9, 3.850319801525264*^9}, {3.85032103377462*^9, 
   3.8503210348924327`*^9}, {3.8503211318377414`*^9, 3.850321133118431*^9}, {
   3.850321416387694*^9, 3.8503214166865964`*^9}, {3.8504127744891553`*^9, 
   3.8504128370980167`*^9}, {3.8504135584175725`*^9, 3.850413648134063*^9}, {
   3.8504136819667025`*^9, 3.8504137392553015`*^9}, {3.850414443255845*^9, 
   3.850414473948425*^9}, {3.8504145181511493`*^9, 3.8504145583762283`*^9}, {
   3.850415710002592*^9, 3.8504157140047865`*^9}, {3.850445719534058*^9, 
   3.8504457200500875`*^9}, {3.8504462769349394`*^9, 3.850446292270817*^9}, {
   3.850446491399206*^9, 3.8504464916532207`*^9}, {3.8587563501119375`*^9, 
   3.858756437184918*^9}, {3.8587564845346265`*^9, 3.8587567507808547`*^9}, {
   3.8587567813296022`*^9, 3.8587568054129796`*^9}, {3.8587568376558237`*^9, 
   3.858756969177346*^9}, 3.858768596445388*^9, {3.858768717242297*^9, 
   3.85876871747231*^9}, {3.8587687846291513`*^9, 3.858768831918856*^9}, {
   3.8587692312376957`*^9, 3.858769247240611*^9}, {3.858770333915766*^9, 
   3.8587704152434173`*^9}, 3.8587710222461357`*^9, {3.858780633562872*^9, 
   3.858780720322834*^9}, {3.858780769274634*^9, 3.8587807794232144`*^9}, {
   3.8587808813850465`*^9, 3.858780967331962*^9}, {3.858781071461918*^9, 
   3.858781073347026*^9}, {3.858781445186294*^9, 3.858781449102518*^9}, {
   3.85878153637451*^9, 3.8587815579887457`*^9}, {3.8587817628204613`*^9, 
   3.858781786210799*^9}, {3.8587820680179176`*^9, 3.85878207696943*^9}, {
   3.8587821732269354`*^9, 3.858782188456806*^9}, {3.8587822366415625`*^9, 
   3.858782271120535*^9}, {3.858783577532257*^9, 3.858783618914624*^9}, {
   3.858783675652869*^9, 3.858783693904913*^9}, {3.8587837462089047`*^9, 
   3.8587837471129565`*^9}, {3.858784441813691*^9, 3.858784514840868*^9}, {
   3.8587846345237136`*^9, 3.8587846405210567`*^9}, {3.858784675142037*^9, 
   3.8587847020515757`*^9}, {3.8597922931654053`*^9, 3.859792640524951*^9}, {
   3.859792707914744*^9, 3.859792719807824*^9}, {3.859792801874601*^9, 
   3.859792810955041*^9}, {3.8598203997739067`*^9, 3.859820419493967*^9}, {
   3.859820536234212*^9, 3.859820546434402*^9}, {3.859820742358832*^9, 
   3.859820772026022*^9}, {3.859820879823742*^9, 3.8598209268543167`*^9}, {
   3.859820985903463*^9, 3.859820991043998*^9}, {3.859821033903864*^9, 
   3.8598210357388496`*^9}, {3.859824871204215*^9, 3.8598248926913033`*^9}, {
   3.8598250461084385`*^9, 3.859825062427837*^9}, {3.881854412415377*^9, 
   3.881854413753022*^9}, {3.8818544463635397`*^9, 3.8818544517132688`*^9}, {
   3.881854532923479*^9, 3.881854537926545*^9}, {3.881854677939205*^9, 
   3.8818546840533266`*^9}, {3.8818551423025894`*^9, 
   3.8818551635520983`*^9}, {3.8818553063941793`*^9, 
   3.8818553197930107`*^9}, {3.8818553796477575`*^9, 3.881855384588915*^9}, {
   3.881855663623844*^9, 3.88185566560791*^9}, 3.8818557683001757`*^9, {
   3.8818558354041147`*^9, 3.881855845070983*^9}, {3.881855902063302*^9, 
   3.8818559101127677`*^9}, {3.8818559945826597`*^9, 3.881856011905384*^9}, 
   3.8818560708880763`*^9, {3.881856192813423*^9, 3.8818561952722416`*^9}, {
   3.8818562914685216`*^9, 3.8818562945398827`*^9}, {3.8818563832211275`*^9, 
   3.881856393949276*^9}, 3.8818565223408957`*^9, {3.881856831522481*^9, 
   3.881856856762314*^9}, 3.8818569038657937`*^9, {3.881859023648181*^9, 
   3.881859025533039*^9}, {3.8818590879703503`*^9, 3.881859094603594*^9}, {
   3.8818591509161224`*^9, 3.8818592551844234`*^9}, {3.881859285468614*^9, 
   3.8818592870429277`*^9}, 3.881859678042121*^9, {3.881859751735881*^9, 
   3.8818598044725394`*^9}, {3.881860293538928*^9, 3.8818603532665353`*^9}, {
   3.8818606087798305`*^9, 3.881860609738922*^9}, {3.881860676926163*^9, 
   3.881860690747652*^9}, {3.8818607502774415`*^9, 3.881860794897805*^9}, {
   3.881860841449094*^9, 3.8818608441844273`*^9}, {3.8818610727874947`*^9, 
   3.881861135855138*^9}, {3.881861182528983*^9, 3.8818612610788016`*^9}, {
   3.8818625244736223`*^9, 3.881862526814233*^9}, {3.8818649977442617`*^9, 
   3.8818650688023467`*^9}, {3.8818651092565084`*^9, 
   3.8818651287460666`*^9}, {3.8818651657258654`*^9, 3.8818653468711*^9}, {
   3.8818656008515635`*^9, 3.8818657166752424`*^9}, {3.8818659314353313`*^9, 
   3.8818659691256437`*^9}, {3.881866018617071*^9, 3.8818660416974*^9}, 
   3.8818665308178673`*^9},
 CellLabel->
  "In[528]:=",ExpressionUUID->"4a7daf7e-0373-4cb6-ab5d-e7290d330453"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV2nlUjI/7PvApW1mzR2hSCEWE0qKrSGVNSoti0qJCpn2vmWlmmqYp4Y0Q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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV13c8lY/7P/CjJG1tRTppKY2jRfuVlgaOREI6skcce3Mmx+GgrX1USlra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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV13k4FPr7PvCpVFpEO9XJUKJStNN6lxYdYWQtqUFkzdh3hjEMM2Np1T7S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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Time\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 1.5858775665095353`}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.004583333333333334], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV21lsXPtBx/FDW2CAAhNowYEWpqFcTChlIEANAXrapq3bpu3cxff6Lrn3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         "]]}, {
        Directive[
         PointSize[0.004583333333333334], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV21lsXPtBx/FDW2CAAhNowYEWpqFcTChlIEANAXrapq3bpu3cxff6Lrn3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         "]]}, {
        Directive[
         PointSize[0.004583333333333334], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV21lsXPtBx/FDW2CAAhNowYEWpqFcTChlIEANAXrapq3bpu3cxff6Lrn3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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Mean Height\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 16.666666666666668`}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd23lcjN/7P/CRLW9bFLJnz5KyFpEXorKWtSKmPa3TvtfU1My0zBSFyJK1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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdm3VcVFvU/hELG8VA5So2FmJdUIxHr4GNgZTooKQC0h3DFDNMgI2KiKiI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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxde3dYlEf39iaWEEtEUYMlZjWoWKJYotiPDVBjXEQFVHTpXZa+9Gd7X9Ao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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Roughness\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 3.954686842545042}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.85982071463521*^9, 3.8598207962096186`*^9, 3.8598209365335655`*^9, 
   3.8598210069160175`*^9, 3.8598210460238266`*^9, 3.859825008807617*^9, 
   3.859826901363695*^9, 3.8818543016181216`*^9, 3.8818544671752834`*^9, 
   3.881854545241785*^9, {3.881855177895931*^9, 3.88185520280138*^9}, 
   3.881855394656602*^9, 3.8818557280739403`*^9, 3.88185585783553*^9, 
   3.8818559282447824`*^9, 3.8818561098423324`*^9, 3.881856201534602*^9, 
   3.8818562487319255`*^9, 3.8818562994147873`*^9, 3.881856400213338*^9, 
   3.88185652871826*^9, {3.881856838353052*^9, 3.8818568627856283`*^9}, {
   3.881856908464223*^9, 3.881856918189989*^9}, 3.8818590465136843`*^9, 
   3.881859096770907*^9, 3.881859260893509*^9, 3.8818592926409483`*^9, 
   3.881859330906748*^9, 3.881859731786583*^9, 3.881859769484559*^9, 
   3.8818598194426603`*^9, 3.8818606255618286`*^9, {3.881860688807166*^9, 
   3.8818606956511936`*^9}, 3.8818607303275857`*^9, 3.88186080024776*^9, {
   3.8818611164468875`*^9, 3.8818611410253725`*^9}, {3.8818611884682503`*^9, 
   3.881861231613881*^9}, 3.8818612663132377`*^9, 3.8818657423158407`*^9, 
   3.8818659285253677`*^9, 3.8818660565244875`*^9, 3.881866981641588*^9},
 CellLabel->
  "Out[538]=",ExpressionUUID->"2e83cfd7-8570-41ec-873d-4fb5fa7000bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"imageSize", "=", "200"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}], ",", 
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"1", ",", "2"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}], ",", 
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"1", ",", "3"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"it", ",", "1", ",", 
     RowBox[{
      RowBox[{"Floor", "[", 
       RowBox[{"nsteps", "/", "nsave"}], "]"}], "+", "1"}], ",", "1"}], 
    "}"}]}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8818608577431326`*^9, 3.8818608698625593`*^9}, {
  3.881860919048889*^9, 3.8818609599840555`*^9}, {3.881860997310582*^9, 
  3.881861027771631*^9}, {3.8818661056831675`*^9, 3.8818661894830403`*^9}},
 CellLabel->
  "In[553]:=",ExpressionUUID->"2af56497-2245-41f9-8c3c-2315fb0625f5"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`it$$ = 1001, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`it$$], 1, 1001, 1}}, Typeset`size$$ = {
    600., {66., 70.0016}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`it$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[{
         ArrayPlot[
          Part[
           $CellContext`results[1, 1], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize], 
         ArrayPlot[
          Part[
           $CellContext`results[1, 2], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize], 
         ArrayPlot[
          Part[
           $CellContext`results[1, 3], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize]}], 
      "Specifications" :> {{$CellContext`it$$, 1, 1001, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{872., {96., 102.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.881860858877551*^9, 3.8818608708657207`*^9}, 
   3.881860931324424*^9, 3.881860961798788*^9, 3.8818610287498364`*^9, 
   3.8818612812576213`*^9, 3.881866190480274*^9, {3.8818669942666197`*^9, 
   3.881867017847129*^9}},
 CellLabel->
  "Out[554]=",ExpressionUUID->"01f90d56-86d1-444c-943e-273826093d97"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Growth with migration, no evaporation", "Subsubsection",
 CellChangeTimes->{{3.8818589731334085`*^9, 3.8818590144666815`*^9}, {
  3.8818624004312196`*^9, 
  3.8818624263415804`*^9}},ExpressionUUID->"12449ad6-0bf2-4c0f-8548-\
7a5a8f843cfc"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", ",", "n"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"40", ",", "60"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iniState", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"empty", " ", "everywhere"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"iniState", "\[LeftDoubleBracket]", 
    RowBox[{"m", ",", "All"}], "\[RightDoubleBracket]"}], "=", "2"}], ";", 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{"bottom", " ", "line"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"nsteps", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nsave", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"model", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "10", ",", "10", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"model", ",", "1"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "20", ",", "30", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"model", ",", "2"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "30", ",", "50", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "0", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"model", ",", "3"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"imageSize", "=", "300"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"myListPlot", "[", 
     RowBox[{"model", ",", "1", ",", "\"\<Time\>\"", ",", "imageSize"}], 
     "]"}], ",", 
    RowBox[{"myListPlot", "[", 
     RowBox[{
     "model", ",", "2", ",", "\"\<Mean Height\>\"", ",", "imageSize"}], "]"}],
     ",", 
    RowBox[{"myListPlot", "[", 
     RowBox[{"model", ",", "3", ",", "\"\<Roughness\>\"", ",", "imageSize"}], 
     "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8502887065634837`*^9, 3.8502888963136773`*^9}, {
   3.850296451864761*^9, 3.850296952605251*^9}, {3.8502970639607067`*^9, 
   3.850297097374488*^9}, {3.850297593896261*^9, 3.8502977479125433`*^9}, {
   3.8502978475363164`*^9, 3.8502978543507624`*^9}, {3.8502978977622185`*^9, 
   3.8502979184872675`*^9}, {3.8502979781423087`*^9, 3.850298044495248*^9}, 
   3.850298075208606*^9, {3.850298134153597*^9, 3.850298229633453*^9}, {
   3.8503051135349236`*^9, 3.850305279617973*^9}, {3.850307256603691*^9, 
   3.8503072838162165`*^9}, {3.850307394898145*^9, 3.8503074024604597`*^9}, {
   3.8503075236844597`*^9, 3.8503075277829113`*^9}, {3.850307577252304*^9, 
   3.850307616956478*^9}, {3.8503077000071898`*^9, 3.8503077034139557`*^9}, {
   3.850307964016522*^9, 3.8503080173115416`*^9}, 3.85030823093408*^9, {
   3.850308287072387*^9, 3.850308376271407*^9}, {3.8503084185719295`*^9, 
   3.85030842657446*^9}, {3.8503085057561445`*^9, 3.8503085116283565`*^9}, {
   3.850308545339714*^9, 3.8503085729720297`*^9}, {3.850308957132331*^9, 
   3.85030896067314*^9}, {3.850309123923725*^9, 3.850309125384981*^9}, {
   3.850309211355878*^9, 3.850309240733102*^9}, {3.850309285394911*^9, 
   3.850309326211439*^9}, 3.8503093778709145`*^9, {3.8503094660718813`*^9, 
   3.8503094670110626`*^9}, {3.850309526303648*^9, 3.850309567884674*^9}, {
   3.85030969600125*^9, 3.850309700258051*^9}, {3.850318495607312*^9, 
   3.8503186014562716`*^9}, {3.85031866995634*^9, 3.8503186723647003`*^9}, {
   3.8503197940242667`*^9, 3.850319801525264*^9}, {3.85032103377462*^9, 
   3.8503210348924327`*^9}, {3.8503211318377414`*^9, 3.850321133118431*^9}, {
   3.850321416387694*^9, 3.8503214166865964`*^9}, {3.8504127744891553`*^9, 
   3.8504128370980167`*^9}, {3.8504135584175725`*^9, 3.850413648134063*^9}, {
   3.8504136819667025`*^9, 3.8504137392553015`*^9}, {3.850414443255845*^9, 
   3.850414473948425*^9}, {3.8504145181511493`*^9, 3.8504145583762283`*^9}, {
   3.850415710002592*^9, 3.8504157140047865`*^9}, {3.850445719534058*^9, 
   3.8504457200500875`*^9}, {3.8504462769349394`*^9, 3.850446292270817*^9}, {
   3.850446491399206*^9, 3.8504464916532207`*^9}, {3.8587563501119375`*^9, 
   3.858756437184918*^9}, {3.8587564845346265`*^9, 3.8587567507808547`*^9}, {
   3.8587567813296022`*^9, 3.8587568054129796`*^9}, {3.8587568376558237`*^9, 
   3.858756969177346*^9}, 3.858768596445388*^9, {3.858768717242297*^9, 
   3.85876871747231*^9}, {3.8587687846291513`*^9, 3.858768831918856*^9}, {
   3.8587692312376957`*^9, 3.858769247240611*^9}, {3.858770333915766*^9, 
   3.8587704152434173`*^9}, 3.8587710222461357`*^9, {3.858780633562872*^9, 
   3.858780720322834*^9}, {3.858780769274634*^9, 3.8587807794232144`*^9}, {
   3.8587808813850465`*^9, 3.858780967331962*^9}, {3.858781071461918*^9, 
   3.858781073347026*^9}, {3.858781445186294*^9, 3.858781449102518*^9}, {
   3.85878153637451*^9, 3.8587815579887457`*^9}, {3.8587817628204613`*^9, 
   3.858781786210799*^9}, {3.8587820680179176`*^9, 3.85878207696943*^9}, {
   3.8587821732269354`*^9, 3.858782188456806*^9}, {3.8587822366415625`*^9, 
   3.858782271120535*^9}, {3.858783577532257*^9, 3.858783618914624*^9}, {
   3.858783675652869*^9, 3.858783693904913*^9}, {3.8587837462089047`*^9, 
   3.8587837471129565`*^9}, {3.858784441813691*^9, 3.858784514840868*^9}, {
   3.8587846345237136`*^9, 3.8587846405210567`*^9}, {3.858784675142037*^9, 
   3.8587847020515757`*^9}, {3.8597922931654053`*^9, 3.859792640524951*^9}, {
   3.859792707914744*^9, 3.859792719807824*^9}, {3.859792801874601*^9, 
   3.859792810955041*^9}, {3.8598203997739067`*^9, 3.859820419493967*^9}, {
   3.859820536234212*^9, 3.859820546434402*^9}, {3.859820742358832*^9, 
   3.859820772026022*^9}, {3.859820879823742*^9, 3.8598209268543167`*^9}, {
   3.859820985903463*^9, 3.859820991043998*^9}, {3.859821033903864*^9, 
   3.8598210357388496`*^9}, {3.859824871204215*^9, 3.8598248926913033`*^9}, {
   3.8598250461084385`*^9, 3.859825062427837*^9}, {3.881854412415377*^9, 
   3.881854413753022*^9}, {3.8818544463635397`*^9, 3.8818544517132688`*^9}, {
   3.881854532923479*^9, 3.881854537926545*^9}, {3.881854677939205*^9, 
   3.8818546840533266`*^9}, {3.8818551423025894`*^9, 
   3.8818551635520983`*^9}, {3.8818553063941793`*^9, 
   3.8818553197930107`*^9}, {3.8818553796477575`*^9, 3.881855384588915*^9}, {
   3.881855663623844*^9, 3.88185566560791*^9}, 3.8818557683001757`*^9, {
   3.8818558354041147`*^9, 3.881855845070983*^9}, {3.881855902063302*^9, 
   3.8818559101127677`*^9}, {3.8818559945826597`*^9, 3.881856011905384*^9}, 
   3.8818560708880763`*^9, {3.881856192813423*^9, 3.8818561952722416`*^9}, {
   3.8818562914685216`*^9, 3.8818562945398827`*^9}, {3.8818563832211275`*^9, 
   3.881856393949276*^9}, 3.8818565223408957`*^9, {3.881856831522481*^9, 
   3.881856856762314*^9}, 3.8818569038657937`*^9, {3.881859023648181*^9, 
   3.881859025533039*^9}, {3.8818590879703503`*^9, 3.881859094603594*^9}, {
   3.8818591509161224`*^9, 3.8818592551844234`*^9}, {3.881859285468614*^9, 
   3.8818592870429277`*^9}, 3.881859678042121*^9, {3.881859751735881*^9, 
   3.8818598044725394`*^9}, {3.881860293538928*^9, 3.8818603532665353`*^9}, {
   3.8818606087798305`*^9, 3.881860609738922*^9}, {3.881860676926163*^9, 
   3.881860690747652*^9}, {3.8818607502774415`*^9, 3.881860794897805*^9}, {
   3.881860841449094*^9, 3.8818608441844273`*^9}, {3.8818610727874947`*^9, 
   3.881861135855138*^9}, {3.881861182528983*^9, 3.8818612610788016`*^9}, {
   3.8818625244736223`*^9, 3.881862526814233*^9}, {3.8818649977442617`*^9, 
   3.8818650688023467`*^9}, {3.8818651092565084`*^9, 
   3.8818651287460666`*^9}, {3.8818651657258654`*^9, 3.8818653468711*^9}, {
   3.8818656008515635`*^9, 3.8818657166752424`*^9}, {3.8818659314353313`*^9, 
   3.8818659691256437`*^9}, {3.881866018617071*^9, 3.8818660416974*^9}, 
   3.8818665308178673`*^9, {3.8818665635572643`*^9, 3.881866631938345*^9}},
 CellLabel->
  "In[541]:=",ExpressionUUID->"de49c4c7-6a91-428f-9470-917ab8604121"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV2mk4lI/7NvBpVX1Lkkqr0YJKUakk5SSVQmQpSjXZl2TsOzO2WTC0I2Va
qSjttGi0ok2WUiqjXSKRSNvfc/yu+8XjjePjmmuuOe/zcHhD3dnPxq0vi8Vq
6sdi/b/v//tqM2L9/1/gfnv55e9Effr5IAz5blmqoG1BVoLu0WHbWw+4klXA
1ykxnjLRjayKpMLwJUtnbiNPgMWsQw8DVkSQ2dCpxYyp1THkybjTPXz1FWU+
eSqG3mD3+6oWT9bAEFFxzfZ7jLWwZ47W83HrE8kzoC4YskJQISBrY9SxDOfF
s5PJs1HFHxw1a3kKWRfjRw3+UjcgjTwH+5M+dN/y20Weiye6481H/mI8Dyd2
jJ7rsHUPWQ/u5V4xJpcZz4fRrA0DL8kyyQvANZbGz9+3n7wQ5quWvkwrZayP
MZc8VfNeM14ELj+hVHN6NtkAs2Zt/VYx5QB5MU4evutUbXaQbAhDpxHzws8d
Ii9B7t0+ahVPGS+F+bd9hyrljI0wRW1siyrvMBmYeapnbMFfMg+oCfia8GX0
EZobI/eAs9l5k+M0N4ae89yAX95klgnkboWSZUeYuQnW+FvqrDTKpfkyBIm/
Jk93yqP5Moh/Ds28vp/MMsW8LtXBkw4xc1O0fhxxJfgRM18O/S/rnj5ZdILm
y6G48WhTzioyawV+Lba2Uatj5itwuNXsxwPWSZqvxOZ55h/3+5F5K5E1fcpq
2xunaG6GxxFX7+vuLqC5GbK1j9tabj5N81W4/WzHhElBZN4qaMrNtTtimPlq
rKjLKlbpe4bmq9G9hncgfVkhzc1RkNKydqIlmWcO27m7BdvOMHMLbBsf0fz5
AzO3QMOMxhkOD87S3BKW9VNqrmqfo7klEOU0facrmbUGpf2XnWCVMvM1cFRJ
TeXcYuZWuM2/9M/lNjO3gsWvMW/D7zJza6wI01Xf+5oMa3zX2Lxjv9d5er01
5huJBsZnkWXWEDbsmu1ZTWatxUKjQzn20y/Q/lr4ttz+U6RD5q3FLv/LVkpp
F2l/LR6pva7uuU9m2WCsYcq8uV1k2KBwXeTR9X0v0b4N7trc82UrkGU2qPQO
Uhiw5TLt2yIyMylY5QEZthjskB+qOaWI9m2R7Goucd1HltnC6K1Xg2cumWUH
6zEPvTNHFtO+HVITguboxZF5duj4bmlj9Z0ss8PcRxHpz/Su0L49bnzx8nGx
JMMeCe+Ub1vakXn2KG9ZyhG6kmX2GBK54tWMncz+OnjXr3owZMxV2l8HXdHQ
WrMnZN46vBy3TuXoC7JsHQwyHsSHCK7R/nqcy9rSJaklYz3ed9fbPXW4Tvvr
YXSobbBFBlm2HrlJHSr+U0to3wE5pwpffOOR4YA154epND8k8xxg2/VvVVUL
WeYAV9+l7HbBDdp3hOaIHcrRT8hwxPWyW+dODJfRviOiqgxjP40jyxxxxeTu
w8MTyawN8N4d3H+6BhkbIO8R6Lj7MPsbYJDnOC5EzOxvQPoYa65nKrO/EUXN
8owOCbO/EbsN5rrmnmH2N8IwvbGxSLWU9jfi3bvl7HvaZJYTFCU9N919yHBC
bsjFA0oCMs8JR/+dGD9zB7PvhMqjCl9mX2L2N6FCtdhf8JvZ3wRP15N6a1be
pP1NiHQu3n0ghizbhD79nhd83U1mbUarTeWtNcfJ2IzCkRpOwnxmfzOijAar
1xUz+5vRtWfc0TPdzP4WDBy+7aWT0y3a34LBcWMmbQ4j87ag0OzGGp0jZNkW
vAz+oDWijMzi4K1VX9/Hprf/ZzYHbvMbdhuYk8FBv5vJD1ZmkzkcjDVTdtp2
i8zjQEPlvN1o2zv/s5SDkpqlsX8CyTIObEz8bn45dfd/lnOwY8uB54nFZNZW
tDyw/hxyjczeCjX7kytdbt2j+1sxP3J9ufJnMmcr+m64cIOnVkb3t+LASsOk
FRpk6VYkyRYssjUmy7biwtfHMa5byPKt2BtaGCm9RmY5g2Xykd+kUk73ndHv
s62nzhgynFFrqvfk4VYyxxkZX7+6priQec4QtMrE0bFkqTOyDXMkIbfJMmdU
trb4DrtHljvjlFL47ERWBd13gRevqfgmY7YLGksfDn+3jAwXBJyMgr41meOC
JVcyDGy3knkumKSwgm0VQZa6YMKMkW5Xz5BlLoh4lTpmTANZ7oJ/iy9FNzcx
910x1sY8TnvTfbrvii7jDl3bYDJc8eOUkZ3CHTLHFVUKwYta1B7QfVfsPJZf
8syULO19/QolxZeOZJkrvp1Tc5jrS5a7IndcVuvlHDLLDXGzsk4VnSaz3SCf
tyWX3UyGG6pLltiIvpA5bsivaPkc3sHcd4NyWUpwcSdz3w3BahwbleEP6b4b
nD3Y58+NJMvdcHt7aqnQksxyh0W/1uM6xWS2O/Z73mzdWE+GO/ye7W5c2Uzm
uEPTwMex+y+Z5w7e0hU3fwx5RPfdcWuKwijlyWSZOx62O6ycv5Esd4ei9t27
FmlklgfC+rr0bCogsz3w4WO+p85TMjwQ6tXy+PN7MscDcdNGev1c85jue2D+
rrsNg+rIUg88a/nXkb26ku57wNvT6OVBHlne+36Hwr74icgsT2hvsg1TTyGz
PdHVsvznz5NkeKJh3g5RfiGZ44kvD4N9tM6ReZ6Q6b+Z/4Sx1BPjhhwcbHSJ
ue+J1BeHUlffYO579v79H92l8pi574XqoVW726uZ+16oUDF+k9HA3PdC8qSl
UvdG5r4XStDHtOQnc98LOaveatb8Zu57ITejRHJH+wnd98Kxe5FKD+eT5V6o
rw7P6dlKZnlDxT+kxsmLzPZG4aoXYRZBZHgjY1P5val8MscbWffzjIclk3ne
COWa625MJUu9oToKQy/uYe57I0rS6Vl2krnvja8Hr1YOq2Xu+0Bg77JWu565
74OTC+7uP9PO3PdB4qeAx29+Mfd9MOXxuW2XFavovg/+FIye9keDLPXBt0d2
l7k6ZJkPYhfK9ow2Ist9UJ/I051uRWZtg8roXTvubCWzt6GYV+tYFETGNgxf
vCbl6VkyZxtyJvxdPOMyc38bno88dFKxhrm/DR3HzlvcesHc3waDIpb1YNVq
ur8NRTZD1jSwySxfrFwb1bB7KpntC42X7/42G5Lhi5qStApFYzLHF6tf7Poz
eDOZ54vMkFNHr3qQpb4Y9I+7o4FLlvni4ItKr9UBzH1fKCWp5roHMve3w/3+
0vnrW5j729F47Fnysk7m/nbE37+oLe1m7m+Hvufod7Z9auj+doQ4frKaZkaW
bsfCN3NmyK3Isu2YLDVcLIwky7djkFHnG4ckMssP781vSE5mktl+qJn9b5Fp
Lhl+aH0w2iqKMccPUUrZ06/XMPf9IIyNLMp8ydz3w/nkudwpH5j7fsjS3zxw
aTtz3w8Kr3aqzNeppftcdI3Y8XmOJ1mJi4XzFgy9FUdmc3FnaIWgLpusy0Vz
92U7z+9kcFHPHevcofD0f7bmYu22NzPchpM5XAx2LTr/nxWZy0V445MvSWFk
HheyGM1FsTxyOhecp3t9WHvJUi6+XxKnOUnJhVxkfQjZEcJYxoVmrrfarXxy
JRetPz9lDX9IlnNhalksCq4nt3ERXS7sW9FDZvnD2VnnmfwPWckfwZFDg4f/
JbP9sTPdpOzbgGeU3x91Ifv/eS4kwx/Zo+ekzl9OtvZHY/HxKZdtyRx//LnG
sZF6k7n+OJY9fEDfMDKv9/15/Xa+3UNO94f3CNtzF4+Tpf7YH6G+aVEFudAf
5b+79De+Jcv8McG7YpLGB3KlP54e3FPPaSLL/TE1W9Xb8Du5zR/awpJd9YPq
KH8AWHPWPh+uQlYKwDppP8PYsWR2AFwUDpt2jCfrBuDBdf68HEMyAlCVa9yx
aSnZOgCuEafdZaZkTgAumGxWfmhO5gZAsuGaUjSHzAvAdLOPr5MiyekB6DTJ
mzA9iSwNgIe98FRCFrkwAErV4nzd62RZAJadvF3q85BcGQCvGf1NNR6R5QGo
b8zdI3tKbgvADsvn/F3Kzyl/INaJlzqqqJOVej3DZmeKFZkdiOU+xnahDmTd
QNyUBfZrzyUjEI9eGmlaFZKtAzHPzvxD6zkyJxAqZyQvfKrJ3ECsXlFtePsl
mRcIS9/JGnrvyOmBgH7/RX79XlD+QAw4PMf5AZtc2Huv5mv938VkWSA+vAn5
s3IpuTIQtyvVdvFXkeWB2J6sqHDNhtwWiDeZvyYXrCOzgrDjxr2kZZvISkHY
vfyvufoWMjsIe9+deLaasW4Qvjpk+RqEkRGEJt6M2mEisnUQ+iY+vfDkPJkT
hPLqnoIPd8ncIMTNiKn5pFNP+YOQeF51RcJScnoQzjU4ZZ9xJUuDsOfl0oIz
EeTCIEh1lgcaJJJlQWgoySuJl5Are+ebBhS47CHLg2DzeLXaygPktiDMSF+r
bZ9HZgXDMbVrn7yMrBSMsRPGd959RmYH43rDKssNjWTdYBxfksea9Z6MYFxm
ey8ybiZbB2PP2hfpHt/JnGC83PBmVXsnmRsMZ3v9VWv7vqT8wXhsH1YeOJSc
HowlKyN2LhhJlgaja7hZ8UQ1cmEwrmYN/GY1jywLBpf9Kz81glwZjDvluucG
JZDlwajxO7xtWiq5LRg6yth5mjErBBNdTqQclpCVQrDXdH9Px14yOwTT7+ga
qLwh64YAN5U6bFrJCMHzoDM/bv4kW4fAumPhXJ1pryh/CJ5+VTeYsI7MDcEM
Kz2lEFcyLwSc2ku1LiHk9BAotOTxZoaTpSF4qy5q92dcGALXOLvXlRFkWQgi
ls77zBeRK0Nwlt/VuiSNLA+Bld/OB9E55LYQiG7V1BbdILNC8eXujP98H5CV
QiHmd/u+f0VmhyKtYdhetVaybiiyZT83WLaREYo946ZlD/pGtg4Fp2zXgV0D
XlP+UPiu+TDmwVgyNxQPTp/8XDuRzAvFgiNnFfLNyemh2O67cKaVBVkaCmFK
YhLXm1wYivkTPs/VF5Blocjc7grFfeTKUPyc9mtORwZZHoplCTFzdTLJbaFo
KXr37f0lMisMewpv9qgVk5XC4G79myesJLPDMP+i4cmTL8m6YZhmarlnl5yM
MNwvPqd9splsHYagb2obbJQaKH8Y7iTafl+iRuaGwXNBduzcKWReGEoLWtae
XU9OD8O5LS4vMx3J0jA0fx/3KXsTuTAMFps71J3dybIwNC3KjrkdSK4Mw8AT
NeWvzpDlYdA0TDzXc43cFoZZPJ2JyaVkVjhOL+ZvCGgmK4Wj++MRtmkHmR2O
L/ELGjxYcsofjp5h28pvDyMjHOdCZsi/TyVbh+NRQ+Yw5ZlkTjiunWqcNm82
mRsOtRF5im9MybxwzBh4S3u0JTk9HEEHb0e+XkOWhsN4u39rtDW5MBwPWzoX
ZNiSZeF4FSlZMNWXXBmOrNbZOq+5ZHk4blzsMf0QTW4LR2lV9Oz4GDIrAsNS
dH73EZOVImDjV/XvDmN2BOyFByuMspj8ERiYKix4zBgRuOr56ESblMkfgf3e
44Ltc5n8EbjorXBo5SkmfwR2s7bFfzzP5I8A//k/Z4mMyR+Bnp/qylV3mfwR
+OM0qXpBLZM/Aq3eQ3ZEfGLyR2DfvZPyA1+Y/BG48MOghNXG5I9A+8ehtYGd
TP4ILLq+3qrf1EbKH4nxa8otn84nK0XCoUrnZfcaMjsS238p3v4QQNaNxP3Y
96VzgsiIhBfn57XbIWTrSIjOFJiujCRzIhFSr/+1NobMjYT3YKeWpzwyLxJF
W8b1eRJPTo9EwWbWul8ZZGkkCm1Ex/NPkQsjMY41y2f1BbIsEntfhPukXyVX
RqLx5JBVfZ6Q5ZHwP/1iqddrclskMibXGe38wOSPguuVDyHbvzH5o/Drp2P7
+E4mfxSeW9xYmNTN5I9CTeWuiocKbyh/FDKehX/pO5hsHYXsu5L6A0PInCis
Dc6pfTeJzI2Cgp3ZoL6zybwofPIw6jN8Ljk9Cn7+E12mzSdLo7Dz99Vn4rXk
wijsmD+rNG8zWRaFIyuajpzeSq6MQp9rv/o+ZSyPgnXrfTNvV3JbFDa1+45v
jSSzojFkg4ZhE4+sFI2HCZ9zLgnI7GjsC/iofeEEWTca+PA9OLuYyR+Nzf33
zv9+j8nfu/+gsUOzjMkfDcXT7G/bK5j80XjfNuLO5VomfzT2BvxW86ln8kdj
ec6AoXENTP5oRFnofOsc+JbyR2OXh8sAi8FkWTTEJyaOLx1KrozGbGX+6+lK
ZHk0rIqFpRv0yG3R+N407eO/ZWRWDJwCQ5vcbclKMXjH+eM1Yj2ZHYOsHxPN
v2wi68agSVp+c7wbGTG4L6nvs82DbB2DDP0HCVO9yJwYfNjn13EmkMyNQY77
ithMMZkXg7U9Rp39D5DTYzDqUY37uPNkaQzUVzVcff2QyR+DkgbtFq8XTP4Y
uLgNOFbcyuSPQcK9I6tvfWPyx2BOD6dChfWO8sdg/N60oz+GkVmx2H7AZP98
ZbJSLNzmrwvzGE9mx+LkqIhbY9XIurGYWve7wFGbjFhwL/np5ZmRrWOx5MfM
nTcsyJxYTHQ2sRhsTebGYodZ/GMrxrxYNO0teW+xiZzeu784ybHSgyyNxe+7
Dp7+oeTCWOiOXtVZm0WWxYLlbfuuKY9cGYsnTvnzXxaR5b2f3/5U5p9HTP5Y
6Fe0RQ99yuTn4feCYuNH78mDeIgZnHbswyfmefBgtWjuHt0vZFUeJk3N2vGp
h3k+PHCHsbTqfpG1eNiwQUfb9R/zvHiIV5n27FSf9/+zPg/H78gHsFTJ4KFj
8fMriVPIZjzcGKvV8p2xNQ+3Gn0H6E0jO/BQ7DGwQ6hB5vDQpaqWa6tJ9uQh
0uQeO2gRmcvDf+N3P18AchgP6Zk3+u9fTebxev+eDTvrZ04W8qAzpot32Jqc
zkPyhyVn9TeSM3gwOW47ooBDlvY+n3h2/PE95DwerimElihIyYU81H5wPTai
hFzEg6Qtp7OojCzj4Sznx82uKnIZD293n3OT1ZEreZhQ2bDB5Su5joe4P5UO
6e1kOQ/zDea9N1b98D9/4uHnrNuOX8eT23jYJPXG6MXkbh5qQnWGSZaSWXws
3d+94rYleRAfPScqkzLWkJX4GJPUpL50LVmVD7fuN6tXMWbzcWDQc+taD7IW
HxmV8u33vMi6fFRrlGaacMn6fPw2OLJBlEYGH2P76LGz95HN+Njs05bfztia
j4NHJx44dIDswMe137de/zlC5vBhoZnZrJBP9uTDqO+IMymMuXxU1ZaaXb1I
DuNDx9Fk0ehrZB4fT0rjlinLyEI+BBwjLQ7jdD4UN9kunXyfnMFH/d+8oRaV
ZCkf158G/PNinMdHftG1j1015EI+rlx4aJD1jFzER8GtpSFJz8kyPh5dKG1b
8IJcxkfW9wlvBr4iV/LxU3WvQeZrch0fs12M7SubyHI+LteeszzfwfTPR8zH
aUs8/jD985F+T3OJVOkj9c+H0GjRX8txZFYcKjRmfe+ZSh4Uh6uGulrfZ5KV
4iA5flurXpusGocNewLG6s0ms+OwpTTE9YghWSsOO4zmt8OIrBuHh8ctY5aa
k/XjsNffcpetIxlxEL44scPPm2wWh4RLLwPytpOt49B/mUnmqhCyQxxa9Url
ywVkThzKrIfcamfsGYfD47o2b5CSuXEINxwyqu4UOSwOH1tbV9pcIvPiMHmc
6orJ18jCOKyrzBL0KSenx+Gegts+v0fkjDjorRw58dhTsjQO9WfUd6KHnBeH
lkeW6iGMC+NwZciMufd+kYvioNJSpDhh5CfqPw6Nb3ZO/z2GXBaHREtea6I6
uTIOR4MCzCunkOvisLJuuIXTdLI8DtMbNeW3GX+Kg3qX1dxSbXJbHHZl6Y2P
0yd3x0FhiC2v3YDMiscI5wDF1CXkQfEYVt1+cZgxWSke6bZjeu6ZklXj8ed5
5YdtNmR2PLTr3h6wsyVrxcMk58NbzfVk3XioyzwKa5zJ+vHQMNnHs3UnIx6e
BvevnQsgm8VjdpfeySeZZOt4OCSPyzM7RnaIx9CWAS2bj5M58QiwPpfnfors
GY8qdRfxvAIyNx7XRBss/ztPDouHmqCkeGwJmReP9z91+SmlZGE8hmdvEOs9
IKfHY/zgHOsaxhnx2GWUJv1ZRZbGY33ZryUBX8h58Qjd6rbjbxu5MB6xxStj
jcY0Uf/x+FdQrJYzniyLR9xggUXeRHJZPM5ursqMUyNXxuOZzs9uWw1yXTwK
btvGGs4ky+Nh/+hEZP/F5E/xONGk+GzlSnJbPHb8XcZWW0Xu7n1er84vWr6a
zErAsdHbQvuvJQ9KwIOuNSl3GSslYLpHTuQXG7JqAiTvS0qm2pHZCfgVMfPw
+GCyVgK60wJHy3PJugkwKX7qHVxA1k9AySv/yLzzZCTAZdUes/y7ZLMEaI1y
/nS+gmydANa7hweyq8kOCei7O3T48HoyJwHNSXHhdo1kz9593ohLnxlzE5Ay
Q/OdejM5LAGjf7s7zxv7mfpPgN2n6XnzF5CFCbjzrfaPiTU5PQEn6gs6p9iQ
MxLgN3fB6ApfsrT387iPaL0SRM5LgDB9q97XGHJhAtRsuq2mx5GLej/fmcm5
30RkWQJ07GRDctLIZQkYn3b57ppMcmUCjtba1xRlk+sSMC7u2d+QPLI8AU8e
VAS9LyZ/SkDYih9NWSXktgRwnSaeyr9L7u59//nNs6bdI7MS4ejQPWfFc/Kg
RLz2m1pyp4mslIiU7Bed49vJqolwePz0OgY2U/+J8DvxZeHe4WStRGyE7oSu
8WTdRDwrV37xWZOsn4jbnOWTH84mIxG6l2zq1E3JZol4lKU40WUF2ToRs27d
SbZZRXZIxMnVrjtazMmcRCxuDRg1fQ3ZMxElYRd9fm0gcxMx+Jt+ubM/OSwR
c2rCro+KIPMSsS+wx0IliixMhP6A9xaKCeT0RIxVPazkuZuckYhsQ7tAy/1k
aSIOPWA923aFnJeIzsDeX5pqcmEith3XPrzzJ7koESvtpxe/G/CF+u/d3wRZ
4RByWSLsJ54LGzyPXJmIdd9vVv5YRq5LBD/uwIWC5WR5ImRuKSuGrCF/SsQ/
38TqLHtyWyJqFe480OSQuxNxvvSKS7UPmZWELRNObRkUSB6UhOt3sww8EslK
STA+NtioUkZWTUKNzuuX5bVkdhIGiPjTP9STtZLw42DDu6hWsm4S9siHr3r0
g6yfhNHVts4ju8lIws6GsuvvFFqo/yQMrXwxsHw02ToJORqmbzzZZIck1G7s
09KwgMxJwkXlsL63VpI9kzCT0/F0kT2Zm4Q/Wxbn999CDktCqXJe5AVXMi8J
6dg8YWs4WZiE9t87DlZHkNOTEN898o9tMjkjCf6CdVdXScjSJFS2OU1q2kfO
S8I6wcuf7hnkwiQUNpyJND5ALkrCv7GOvjfOkWW9+zXn2/deIZcl4dTWw6/q
npArk+BW8vdY9Q9yXRKuVmfWx3aT5UlYuihqIbt/K/WfhPKERknOaHJbEhIu
JujM1yR3J6HqOOvHET0yS4AaR9UsHXPyIAEKcgodva3JSgKYOh34KUohqwpQ
dc9kzX8SMlsAt0OP9jUdJGv17oft/jL1KFlXgHnbjX3s8sn6ApTVJNUWXyVD
gMbAJdWxd8lmAkx5vy3/2D2ytQDep/6rzn1CdhDgKTd8y4zfZI4AB2+fF10Y
8JX6F+C84vuojQPJXAEuGFjv7VIjhwnAUTNpMDEg8wRoFXRwHKzIQgG6mw5v
vbOJnC7AK7GD6Y5UcoYAJtZ2WJtGlgowoWp1atEucp4AG5d5TTfZTy4UYJgl
t+B9AbmoN9/CGB3NIrJMgDHvkvocZVwmwNkaY1bnTXKlABv0Gpf8aybXCVBv
LYwqbiXLBcjxOlWU+YP8SYB/bd/StP6R2wQw4lUcN+hL/9ffLcDenVc/aI5n
/s9fiNahgwV7J5EHCXHnUc+XFHWykhBumpUa3hpkVSEmN57fvVaHzBZi1CXn
q8P1yFpCDC5YaMZdQNYVoswgbUIGY30htp9o2DjUiAwhjtqKvUaAbCbEpjnH
cn0ZWwsxYlOfijxLsoMQ/hUTYvasIXOEOKH368ZNR7KnEH2vbt0y04XMFaKf
SHdRtjs5TAixc+k/fR8yTwjVbJcPfH+yUIjEM+/vZAWQ04X4sNV62q0QcoYQ
A0Y/cxgSSpYKYSIRa6owzhNCWLrT4EAMuVAIW+Mui4Gx5CIhDNfFpWcnkWVC
XLXr3i8WksuEqLC2mjR+L7lSiN/D0n0nHCbXCfF0Y+iLqKNkuRDxK9abvT9G
/iTEkPVHFD4ybhMi7YL+2/STTP+9+QNe3d19iulfBKnfi28phUz/IrzMm/bC
+RzTvwgKSy7b6d1g+hfhkOPvUWNKmf5FiL++q/M6Yy0R2sUVA7NvMv2LsLhY
mNjJWF+Ev/OiFX1uMf2L4Lk4eAWXsZkIKoq/VFxuM/2L4JX1n3bAPaZ/EfJV
OS+1y5n+RXi2OEF5Xw3Tvwj+ikbSEy+Z/kU4Prlz8aAGpn8RXkRw+ojfM/2L
UJJi/qKSsVCEfv81G2p8ZvoXoaZiucGVZqZ/EZ5n6fYZ38b0L0Lki7P5qh1M
/yLwsr+fPvaD6V8Em+vxb68xLhJh82O9gbY/mf5FyBYVqHv8YfoXIWeHd4sl
6xv1L0Lg069rbIaT60SwLve5eXo0WS5CaMqeeoMx5E+9+1d6HlyfSG4TYV6f
hFfnNcndIoilpf8Mp5NZYlS5/ehTN5M8SIxWi39pg7XJSmJMNu9nr6NDVhXD
WPlL1V/GbDGeTT0xvmoBWUuMic0Tp+gbkHXF6Lm+0CJnCVlfjFM+t31qQIYY
jn3PDP1iSjYTw/7Cv6XNy8nWYnRy7g+8Y0N2EOPk1MtjD28kc8TYkuuxW9ed
7ClG038bvbS8yVwxPiuMOz6TcZgY51w6wn5zyTwxTGpsOU/CyEIxSgeuD38R
SU4XY9SVTtMxseQMMVY9l3T5x5GlYvQLcIxsZpwnhl7R3mDFRHKhGPtn7T68
LJNcJIbh8dwHxjlkmRimJRfuFB8jl4lxhW3Ylnqc6V+MlZUuyj9ymf7F+P0t
n7/6PNO/GEvih23OYPxJjDTx25Nal5j+xfgT5O1uWMz0Lwb7o/LbGVeZ/pPh
eGnZAvZ1pv9kjIuZGFlyh+k/GbfzW5fzqpj+k7F/xrriOMbsZPQb65gXUM/0
n4ynzgu6qhjrJmPDGXXYvmT6T4bgvYOa0Wum/2T00Z23jtPA9J+MZZcEI1fI
mf6TEexePdybsUPv+/Wd5ruvkek/GZum3quLb2b6T8a2ztoK7zam/16XsxSt
epj+e9/Pb6n62b7t1H8yLu7vzFo1gCxMhsbt8L4W/5HTk3FzuPFqv0nkjGRk
eLi9mDqZLO39vDLtEK4WOS8ZD1xjzf7OIBcmQ1no/tdyJrkoGaElb3242mRZ
MvydHM1aZ5PLknHWeJCSqSm5Mhl+jsXXhIzrkqFn32Ghu4osT4bihDmuamvI
n5Lx0J69pciO3JaM4i35S/46kLuTMWb3w9WOW8isFNicb/Niu5AHpSBcb33V
aleyUgoaKxTuGbuTVVNQnvunppwxOwXnbk4Ki/Yha6XgTCSbs8yPrJsC17yT
DfWBZP0UBJWNiZ4QTUYKOE0LXUP4ZLMUlOTV7K9LIFunwH7nNXNFMdkhBX+n
q4xrSSdzUrBf37Co5RjZMwUd3QMKlueSub37E8qKr+aTw1KgPHHYO+NzTP8p
2DP5/qgLF5n+U/Dy8ZN828tM/yng3a3ZP7uI6T8FerrvPJ8wlqZgxrCPp6Qy
pv8UDOONm7zlLtN/CoxlIy1PP2f6T8HwHw7LOhuZ/lPw5E+hoOgj038KBq37
Oqf8C9N/7/Ma9XulYivTfwraLg75atjO9J+C5Z8mmz7uZPpPQU6XhuPev0z/
KfijZjcsb3AH9Z+CrWVSDZ0hZFYq3pe/Npo6nDwoFd2zsmV3RpCVUnHKr7Hp
tDJZNRU6Bj/aXo0ms1PRlnr2mvoYslYq8romvymaTNZNRc+rge6vGOunYnHP
sMk7p5ORisQF5Rpb9clmqZhw2dO7zZhs3bv/bsrC74wdUuFuUTxw5AoyJxVz
ngovjlhN9kyFb//+wxfbkrmpEAXcP2e5nhyWiskWVcddNpJ5qehn3O6ErWRh
Kk4mLK9z9yenp+LqscKoH6HkjFS0mntYjokgS1Mx22ZxT2kcOS8VQyxHfW0X
kQtTUWQ0c1RPCrkoFY1PzmibppJlqdjsWR3gICGXpaJ96te3rgfIlalgPRCZ
Xz9IrktFc2faif5SsjwVN/Myq/IPkT+lQjnpmY/3UXJbKmwskif6HmP6T8Xa
LcftrzFmSVDenJueeorpXwKDMeJU81tM/xLI7zQ/XXGH6b/XPuGXb91l+pdA
ECFbZVTB9C+BTpr6UNF9pn8JyiYlhrU8ZfqXIGPFuIMZr5j+JbiyS2fwwjdM
/xIII2OGbv7I9C/BiP+cXFNbmf4leJ+Trf+3jelfAq7y7PGz2pn+JTjeLE38
9oPpXwLXkI4pbl1M/xIcWW8i+c76Tv1LELubn1nQjyyUwP5twPOEgeR0CU4p
L7toNJicIcG/8ztSLiiRpRL83mk/cZ8yOU+CZZ151c9UyIUS2BVqnrk5gVzU
+/qw+dtyNMkyCUZ1rTxZNZdcJsH5eTz+c8aVElxYelO/aBG5ToKc0kMiDUOy
vDe/3eSuE6vJnyRY+KNU4znjNgk0A0em6lmRu3vzLWw3/mJDZqVh4mVFaaYT
eVAarB7mdx3aQlZKQ0jitnnt7mTVNEiWfZVt9yCz03DyYT+7kWFkrTTYu42V
Hoog66ZBy29DZEMUWT8NTT3FThZxZKRhnfllt8NpZLM0KGtwNaR7vhv9H5Yu
pgg=
         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV12k4lI37PvBpk6cnopWkJqmkTVFp4yRJ+0SyRCYku7GPfYYxZsYM2qR9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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV13k0lI/7PvBpUUqLitA6UlIiLUKLrhZSSRPZyViyx9h3xtjGGEsL0WZa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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Time\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 1.286529684208635}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd1FtwXPddwPFDy0XcN1BAgQJbU4qaYZiFcBEE6Gnrtmpx221SN2oTpxvf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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd1FlwHPldB/Am4RjuEQSQIMBEhCBEQg2YQ2AgncRJFOKE2d04qz20O/ba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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd1FlwI/ldwPEm4TC3FgJ4IYCyhGCWEAThMARIJ9kkTrJJtJs9vMfs9tye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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Mean Height\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 15.583333333333334`}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd23lcjOv/P/Cxniwpe/axlzV7xPGyREQmiihMCaVt2vea9qmmKRwKYSzH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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdm3dYVNcT99eCQTEBxYIRzVpQ7KhRsX9FFOyAqCiKi9KkLr0sZWFh2V2W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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdm3dc1Me39/dnC7aIYsGalShix06sH1ERNSpYUURXEEGKLH3pu+wu7C7L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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Roughness\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 2.702739769176272}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.85982071463521*^9, 3.8598207962096186`*^9, 3.8598209365335655`*^9, 
   3.8598210069160175`*^9, 3.8598210460238266`*^9, 3.859825008807617*^9, 
   3.859826901363695*^9, 3.8818543016181216`*^9, 3.8818544671752834`*^9, 
   3.881854545241785*^9, {3.881855177895931*^9, 3.88185520280138*^9}, 
   3.881855394656602*^9, 3.8818557280739403`*^9, 3.88185585783553*^9, 
   3.8818559282447824`*^9, 3.8818561098423324`*^9, 3.881856201534602*^9, 
   3.8818562487319255`*^9, 3.8818562994147873`*^9, 3.881856400213338*^9, 
   3.88185652871826*^9, {3.881856838353052*^9, 3.8818568627856283`*^9}, {
   3.881856908464223*^9, 3.881856918189989*^9}, 3.8818590465136843`*^9, 
   3.881859096770907*^9, 3.881859260893509*^9, 3.8818592926409483`*^9, 
   3.881859330906748*^9, 3.881859731786583*^9, 3.881859769484559*^9, 
   3.8818598194426603`*^9, 3.8818606255618286`*^9, {3.881860688807166*^9, 
   3.8818606956511936`*^9}, 3.8818607303275857`*^9, 3.88186080024776*^9, {
   3.8818611164468875`*^9, 3.8818611410253725`*^9}, {3.8818611884682503`*^9, 
   3.881861231613881*^9}, 3.8818612663132377`*^9, 3.8818657423158407`*^9, 
   3.8818659285253677`*^9, 3.8818660565244875`*^9, 3.881866641210947*^9, 
   3.8818666947081213`*^9, 3.8818670094823275`*^9},
 CellLabel->
  "Out[552]=",ExpressionUUID->"980c6ce1-f709-4026-889e-ede804d7ef42"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"imageSize", "=", "200"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"2", ",", "1"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}], ",", 
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}], ",", 
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"2", ",", "3"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"it", ",", "1", ",", 
     RowBox[{
      RowBox[{"Floor", "[", 
       RowBox[{"nsteps", "/", "nsave"}], "]"}], "+", "1"}], ",", "1"}], 
    "}"}]}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8818608577431326`*^9, 3.8818608698625593`*^9}, {
  3.881860919048889*^9, 3.8818609599840555`*^9}, {3.881860997310582*^9, 
  3.881861027771631*^9}, {3.8818661056831675`*^9, 3.8818661894830403`*^9}, {
  3.8818666601439734`*^9, 3.8818666793288484`*^9}},
 CellLabel->
  "In[555]:=",ExpressionUUID->"0c5e7ccc-7a39-444b-a757-35968bc51733"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`it$$ = 1001, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`it$$], 1, 1001, 1}}, Typeset`size$$ = {
    607.7, {334.0416, 104.8416}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`it$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[{
         ArrayPlot[
          Part[
           $CellContext`results[2, 1], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize], 
         ArrayPlot[
          Part[
           $CellContext`results[2, 2], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize], 
         ArrayPlot[
          Part[
           $CellContext`results[2, 3], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize]}], 
      "Specifications" :> {{$CellContext`it$$, 1, 1001, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1013., {247., 253.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.881860858877551*^9, 3.8818608708657207`*^9}, 
   3.881860931324424*^9, 3.881860961798788*^9, 3.8818610287498364`*^9, 
   3.8818612812576213`*^9, 3.881866190480274*^9, 3.881866680254269*^9, 
   3.881866723018073*^9, 3.881867027616235*^9},
 CellLabel->
  "Out[556]=",ExpressionUUID->"f1842071-3a5a-43df-b6d1-750d9fecbb1e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Growth with migration and evaporation", "Subsubsection",
 CellChangeTimes->{{3.8818589731334085`*^9, 3.8818590144666815`*^9}, {
  3.8818624004312196`*^9, 3.8818624263415804`*^9}, {3.8818670921447473`*^9, 
  3.881867094605626*^9}},ExpressionUUID->"07909f3b-3bb8-4491-9c4d-\
b497d9734c52"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", ",", "n"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"40", ",", "60"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iniState", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"empty", " ", "everywhere"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"iniState", "\[LeftDoubleBracket]", 
    RowBox[{"m", ",", "All"}], "\[RightDoubleBracket]"}], "=", "2"}], ";", 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{"bottom", " ", "line"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"nsteps", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nsave", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"model", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "20", ",", "30", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "5", ",", "3", ",", "1", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "0", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"model", ",", "1"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "20", ",", "30", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "5", ",", "3", ",", "1", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "5", ",", "0", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "5", ",", "0"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"model", ",", "2"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"10", ",", "20", ",", "30", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"deposition", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "5", ",", "3", ",", "1", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"evaporation", " ", "rates", " ", "for", " ", "1"}], ",", " ", 
       "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "5", ",", "2", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"left", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
        ",", " ", "2", ",", " ", 
       RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", "10", ",", "5", ",", "2"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"right", " ", "migration", " ", "rates", " ", "for", " ", "1"}],
       ",", " ", "2", ",", " ", 
      RowBox[{"or", " ", "3", " ", "new", " ", "bonds"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"model", ",", "3"}], "]"}], "=", 
   RowBox[{"surface1dKMCGrowth", "[", 
    RowBox[{"iniState", ",", "rates", ",", "nsteps", ",", "nsave"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"imageSize", "=", "300"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"myListPlot", "[", 
     RowBox[{"model", ",", "1", ",", "\"\<Time\>\"", ",", "imageSize"}], 
     "]"}], ",", 
    RowBox[{"myListPlot", "[", 
     RowBox[{
     "model", ",", "2", ",", "\"\<Mean Height\>\"", ",", "imageSize"}], "]"}],
     ",", 
    RowBox[{"myListPlot", "[", 
     RowBox[{"model", ",", "3", ",", "\"\<Roughness\>\"", ",", "imageSize"}], 
     "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8502887065634837`*^9, 3.8502888963136773`*^9}, {
   3.850296451864761*^9, 3.850296952605251*^9}, {3.8502970639607067`*^9, 
   3.850297097374488*^9}, {3.850297593896261*^9, 3.8502977479125433`*^9}, {
   3.8502978475363164`*^9, 3.8502978543507624`*^9}, {3.8502978977622185`*^9, 
   3.8502979184872675`*^9}, {3.8502979781423087`*^9, 3.850298044495248*^9}, 
   3.850298075208606*^9, {3.850298134153597*^9, 3.850298229633453*^9}, {
   3.8503051135349236`*^9, 3.850305279617973*^9}, {3.850307256603691*^9, 
   3.8503072838162165`*^9}, {3.850307394898145*^9, 3.8503074024604597`*^9}, {
   3.8503075236844597`*^9, 3.8503075277829113`*^9}, {3.850307577252304*^9, 
   3.850307616956478*^9}, {3.8503077000071898`*^9, 3.8503077034139557`*^9}, {
   3.850307964016522*^9, 3.8503080173115416`*^9}, 3.85030823093408*^9, {
   3.850308287072387*^9, 3.850308376271407*^9}, {3.8503084185719295`*^9, 
   3.85030842657446*^9}, {3.8503085057561445`*^9, 3.8503085116283565`*^9}, {
   3.850308545339714*^9, 3.8503085729720297`*^9}, {3.850308957132331*^9, 
   3.85030896067314*^9}, {3.850309123923725*^9, 3.850309125384981*^9}, {
   3.850309211355878*^9, 3.850309240733102*^9}, {3.850309285394911*^9, 
   3.850309326211439*^9}, 3.8503093778709145`*^9, {3.8503094660718813`*^9, 
   3.8503094670110626`*^9}, {3.850309526303648*^9, 3.850309567884674*^9}, {
   3.85030969600125*^9, 3.850309700258051*^9}, {3.850318495607312*^9, 
   3.8503186014562716`*^9}, {3.85031866995634*^9, 3.8503186723647003`*^9}, {
   3.8503197940242667`*^9, 3.850319801525264*^9}, {3.85032103377462*^9, 
   3.8503210348924327`*^9}, {3.8503211318377414`*^9, 3.850321133118431*^9}, {
   3.850321416387694*^9, 3.8503214166865964`*^9}, {3.8504127744891553`*^9, 
   3.8504128370980167`*^9}, {3.8504135584175725`*^9, 3.850413648134063*^9}, {
   3.8504136819667025`*^9, 3.8504137392553015`*^9}, {3.850414443255845*^9, 
   3.850414473948425*^9}, {3.8504145181511493`*^9, 3.8504145583762283`*^9}, {
   3.850415710002592*^9, 3.8504157140047865`*^9}, {3.850445719534058*^9, 
   3.8504457200500875`*^9}, {3.8504462769349394`*^9, 3.850446292270817*^9}, {
   3.850446491399206*^9, 3.8504464916532207`*^9}, {3.8587563501119375`*^9, 
   3.858756437184918*^9}, {3.8587564845346265`*^9, 3.8587567507808547`*^9}, {
   3.8587567813296022`*^9, 3.8587568054129796`*^9}, {3.8587568376558237`*^9, 
   3.858756969177346*^9}, 3.858768596445388*^9, {3.858768717242297*^9, 
   3.85876871747231*^9}, {3.8587687846291513`*^9, 3.858768831918856*^9}, {
   3.8587692312376957`*^9, 3.858769247240611*^9}, {3.858770333915766*^9, 
   3.8587704152434173`*^9}, 3.8587710222461357`*^9, {3.858780633562872*^9, 
   3.858780720322834*^9}, {3.858780769274634*^9, 3.8587807794232144`*^9}, {
   3.8587808813850465`*^9, 3.858780967331962*^9}, {3.858781071461918*^9, 
   3.858781073347026*^9}, {3.858781445186294*^9, 3.858781449102518*^9}, {
   3.85878153637451*^9, 3.8587815579887457`*^9}, {3.8587817628204613`*^9, 
   3.858781786210799*^9}, {3.8587820680179176`*^9, 3.85878207696943*^9}, {
   3.8587821732269354`*^9, 3.858782188456806*^9}, {3.8587822366415625`*^9, 
   3.858782271120535*^9}, {3.858783577532257*^9, 3.858783618914624*^9}, {
   3.858783675652869*^9, 3.858783693904913*^9}, {3.8587837462089047`*^9, 
   3.8587837471129565`*^9}, {3.858784441813691*^9, 3.858784514840868*^9}, {
   3.8587846345237136`*^9, 3.8587846405210567`*^9}, {3.858784675142037*^9, 
   3.8587847020515757`*^9}, {3.8597922931654053`*^9, 3.859792640524951*^9}, {
   3.859792707914744*^9, 3.859792719807824*^9}, {3.859792801874601*^9, 
   3.859792810955041*^9}, {3.8598203997739067`*^9, 3.859820419493967*^9}, {
   3.859820536234212*^9, 3.859820546434402*^9}, {3.859820742358832*^9, 
   3.859820772026022*^9}, {3.859820879823742*^9, 3.8598209268543167`*^9}, {
   3.859820985903463*^9, 3.859820991043998*^9}, {3.859821033903864*^9, 
   3.8598210357388496`*^9}, {3.859824871204215*^9, 3.8598248926913033`*^9}, {
   3.8598250461084385`*^9, 3.859825062427837*^9}, {3.881854412415377*^9, 
   3.881854413753022*^9}, {3.8818544463635397`*^9, 3.8818544517132688`*^9}, {
   3.881854532923479*^9, 3.881854537926545*^9}, {3.881854677939205*^9, 
   3.8818546840533266`*^9}, {3.8818551423025894`*^9, 
   3.8818551635520983`*^9}, {3.8818553063941793`*^9, 
   3.8818553197930107`*^9}, {3.8818553796477575`*^9, 3.881855384588915*^9}, {
   3.881855663623844*^9, 3.88185566560791*^9}, 3.8818557683001757`*^9, {
   3.8818558354041147`*^9, 3.881855845070983*^9}, {3.881855902063302*^9, 
   3.8818559101127677`*^9}, {3.8818559945826597`*^9, 3.881856011905384*^9}, 
   3.8818560708880763`*^9, {3.881856192813423*^9, 3.8818561952722416`*^9}, {
   3.8818562914685216`*^9, 3.8818562945398827`*^9}, {3.8818563832211275`*^9, 
   3.881856393949276*^9}, 3.8818565223408957`*^9, {3.881856831522481*^9, 
   3.881856856762314*^9}, 3.8818569038657937`*^9, {3.881859023648181*^9, 
   3.881859025533039*^9}, {3.8818590879703503`*^9, 3.881859094603594*^9}, {
   3.8818591509161224`*^9, 3.8818592551844234`*^9}, {3.881859285468614*^9, 
   3.8818592870429277`*^9}, 3.881859678042121*^9, {3.881859751735881*^9, 
   3.8818598044725394`*^9}, {3.881860293538928*^9, 3.8818603532665353`*^9}, {
   3.8818606087798305`*^9, 3.881860609738922*^9}, {3.881860676926163*^9, 
   3.881860690747652*^9}, {3.8818607502774415`*^9, 3.881860794897805*^9}, {
   3.881860841449094*^9, 3.8818608441844273`*^9}, {3.8818610727874947`*^9, 
   3.881861135855138*^9}, {3.881861182528983*^9, 3.8818612610788016`*^9}, {
   3.8818625244736223`*^9, 3.881862526814233*^9}, {3.8818649977442617`*^9, 
   3.8818650688023467`*^9}, {3.8818651092565084`*^9, 
   3.8818651287460666`*^9}, {3.8818651657258654`*^9, 3.8818653468711*^9}, {
   3.8818656008515635`*^9, 3.8818657166752424`*^9}, {3.8818659314353313`*^9, 
   3.8818659691256437`*^9}, {3.881866018617071*^9, 3.8818660416974*^9}, 
   3.8818665308178673`*^9, {3.8818665635572643`*^9, 3.881866631938345*^9}, {
   3.881867112981105*^9, 3.8818671643342915`*^9}, {3.8818672262931533`*^9, 
   3.881867236724552*^9}},
 CellLabel->
  "In[571]:=",ExpressionUUID->"d7e20dcc-f6a2-470d-b80f-66ebbeaf488b"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV2HdczQ/0P/BLRlbKzKobIRGlNMyX2bBS0kDdFmne9m3fW7fb7d6WlWRd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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV1nk4lP0bNvBpUdJTeVqkqKZI2rVJIWcLabG1SNmmlC3L2Mc+ZgxjGKZS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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxV13lYDOz7NvBBaLEURbKNtbKOaCFxEoqkUAqVkVIqNe17zUzbTMtU1h7r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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Time\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 0.8163904650033404}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd1FlwZOdZxvFDwiL2NgSQIUDHhETloqgGswgM5CQ4iRKcpL2MLccep73M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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd1FlsY1cdx/ELZQm7CwVcKHA7QiiqEDKUxVCgp+20ddtp65l2ZtJZ2ttM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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd1VmMHEcdx/GCcAz3BAJMIEATIbSKEGoIx0KAVEKOScjRduxkY8dJ+x7f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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Mean Height\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotRange -> {{0., 1001.}, {0, 11.85}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdm3dUU1n392PBYSwjigXU0dgQFTG2kVFHvzIW7FFwRBQNvUPooYeEQBIg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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxd23dYU9nWBvCMFTsO6qCiRkRFRwErWNBXRwULGmw0wQiCdELvkkIgJBCw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         "]]}, {
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdm3dYlEfXxtca7CgWFNS1FxRXjRH7bccWQdGgKCwIggi69KU/7LKwC7sL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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"N\"", TraditionalForm], 
       FormBox["\"Roughness\"", TraditionalForm]}, AxesOrigin -> {0., 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 1001.}, {0, 2.452889452598031}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.85982071463521*^9, 3.8598207962096186`*^9, 3.8598209365335655`*^9, 
   3.8598210069160175`*^9, 3.8598210460238266`*^9, 3.859825008807617*^9, 
   3.859826901363695*^9, 3.8818543016181216`*^9, 3.8818544671752834`*^9, 
   3.881854545241785*^9, {3.881855177895931*^9, 3.88185520280138*^9}, 
   3.881855394656602*^9, 3.8818557280739403`*^9, 3.88185585783553*^9, 
   3.8818559282447824`*^9, 3.8818561098423324`*^9, 3.881856201534602*^9, 
   3.8818562487319255`*^9, 3.8818562994147873`*^9, 3.881856400213338*^9, 
   3.88185652871826*^9, {3.881856838353052*^9, 3.8818568627856283`*^9}, {
   3.881856908464223*^9, 3.881856918189989*^9}, 3.8818590465136843`*^9, 
   3.881859096770907*^9, 3.881859260893509*^9, 3.8818592926409483`*^9, 
   3.881859330906748*^9, 3.881859731786583*^9, 3.881859769484559*^9, 
   3.8818598194426603`*^9, 3.8818606255618286`*^9, {3.881860688807166*^9, 
   3.8818606956511936`*^9}, 3.8818607303275857`*^9, 3.88186080024776*^9, {
   3.8818611164468875`*^9, 3.8818611410253725`*^9}, {3.8818611884682503`*^9, 
   3.881861231613881*^9}, 3.8818612663132377`*^9, 3.8818657423158407`*^9, 
   3.8818659285253677`*^9, 3.8818660565244875`*^9, 3.881866641210947*^9, 
   3.8818666947081213`*^9, 3.8818670094823275`*^9, 3.8818672420520377`*^9, 
   3.8818673121588745`*^9},
 CellLabel->
  "Out[582]=",ExpressionUUID->"4d72a15c-db7d-4eed-a911-824e7769a4b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"imageSize", "=", "200"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"3", ",", "1"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}], ",", 
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"3", ",", "2"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}], ",", 
      RowBox[{"ArrayPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"results", "[", 
          RowBox[{"3", ",", "3"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"4", ",", "it"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "imageSize"}]}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"it", ",", "1", ",", 
     RowBox[{
      RowBox[{"Floor", "[", 
       RowBox[{"nsteps", "/", "nsave"}], "]"}], "+", "1"}], ",", "1"}], 
    "}"}]}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8818608577431326`*^9, 3.8818608698625593`*^9}, {
  3.881860919048889*^9, 3.8818609599840555`*^9}, {3.881860997310582*^9, 
  3.881861027771631*^9}, {3.8818661056831675`*^9, 3.8818661894830403`*^9}, {
  3.8818666601439734`*^9, 3.8818666793288484`*^9}, {3.8818672528618326`*^9, 
  3.88186726184387*^9}},
 CellLabel->
  "In[569]:=",ExpressionUUID->"840db86e-0a3f-42cd-aaf8-90c03396bfe1"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`it$$ = 1001, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`it$$], 1, 1001, 1}}, Typeset`size$$ = {
    607.7, {334.0416, 104.8416}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`it$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[{
         ArrayPlot[
          Part[
           $CellContext`results[3, 1], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize], 
         ArrayPlot[
          Part[
           $CellContext`results[3, 2], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize], 
         ArrayPlot[
          Part[
           $CellContext`results[3, 3], 4, $CellContext`it$$], 
          ImageSize -> $CellContext`imageSize]}], 
      "Specifications" :> {{$CellContext`it$$, 1, 1001, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1013., {247., 253.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.881860858877551*^9, 3.8818608708657207`*^9}, 
   3.881860931324424*^9, 3.881860961798788*^9, 3.8818610287498364`*^9, 
   3.8818612812576213`*^9, 3.881866190480274*^9, 3.881866680254269*^9, 
   3.881866723018073*^9, 3.881867027616235*^9, 3.8818672628115263`*^9},
 CellLabel->
  "Out[570]=",ExpressionUUID->"dfd25942-6f4a-4b5a-9199-ad52561ff2a5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1152., 615.6},
WindowMargins->{{
  Automatic, -5.399999999999864}, {-5.399999999999977, Automatic}},
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 12, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"82b3c679-ef90-4721-a13f-474f6ed28a0c"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 385, 6, 97, "Title",ExpressionUUID->"b15229c8-5a8d-4e56-afb3-39951f71899b"],
Cell[CellGroupData[{
Cell[990, 32, 671, 11, 105, "Section",ExpressionUUID->"0df30b08-34d4-4ecd-a531-7a8c91a746de"],
Cell[1664, 45, 41030, 804, 2291, "Input",ExpressionUUID->"ecdda7ec-fa69-4d39-bc74-0c1c937e0baf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42731, 854, 464, 6, 67, "Section",ExpressionUUID->"97799fb6-f47e-46e0-a957-eef0312bf499"],
Cell[43198, 862, 1997, 52, 88, "Input",ExpressionUUID->"73299ce6-9e87-49f1-89e2-3ae98e6a1047"],
Cell[CellGroupData[{
Cell[45220, 918, 197, 3, 45, "Subsubsection",ExpressionUUID->"75f56ec7-339a-4b01-8cb7-fd28b19030ea"],
Cell[CellGroupData[{
Cell[45442, 925, 11768, 223, 556, "Input",ExpressionUUID->"4a7daf7e-0373-4cb6-ab5d-e7290d330453"],
Cell[57213, 1150, 96489, 1633, 216, "Output",ExpressionUUID->"2e83cfd7-8570-41ec-873d-4fb5fa7000bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153739, 2788, 1648, 40, 88, "Input",ExpressionUUID->"2af56497-2245-41f9-8c3c-2315fb0625f5"],
Cell[155390, 2830, 2193, 48, 217, "Output",ExpressionUUID->"01f90d56-86d1-444c-943e-273826093d97"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[157632, 2884, 245, 4, 45, "Subsubsection",ExpressionUUID->"12449ad6-0bf2-4c0f-8548-7a5a8f843cfc"],
Cell[CellGroupData[{
Cell[157902, 2892, 11924, 226, 575, "Input",ExpressionUUID->"de49c4c7-6a91-428f-9470-917ab8604121"],
Cell[169829, 3120, 93953, 1592, 216, "Output",ExpressionUUID->"980c6ce1-f709-4026-889e-ede804d7ef42"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263819, 4717, 1701, 41, 88, "Input",ExpressionUUID->"0c5e7ccc-7a39-444b-a757-35968bc51733"],
Cell[265523, 4760, 2220, 48, 519, "Output",ExpressionUUID->"f1842071-3a5a-43df-b6d1-750d9fecbb1e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[267792, 4814, 293, 4, 45, "Subsubsection",ExpressionUUID->"07909f3b-3bb8-4491-9c4d-b497d9734c52"],
Cell[CellGroupData[{
Cell[268110, 4822, 12028, 228, 575, "Input",ExpressionUUID->"d7e20dcc-f6a2-470d-b80f-66ebbeaf488b"],
Cell[280141, 5052, 90909, 1539, 239, "Output",ExpressionUUID->"4d72a15c-db7d-4eed-a911-824e7769a4b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[371087, 6596, 1751, 42, 88, "Input",ExpressionUUID->"840db86e-0a3f-42cd-aaf8-90c03396bfe1"],
Cell[372841, 6640, 2244, 48, 519, "Output",ExpressionUUID->"dfd25942-6f4a-4b5a-9199-ad52561ff2a5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

